<?php 

namespace App\Actions\Ecommerce;

use Illuminate\Support\Collection;

use App\Models\Registration;
use App\Models\PricingExtra;
use App\Models\PricingGroupPrice;
use App\Models\PromoCode;

class PriceCalculator
{
    private $registration;
    private $price;
    private $attendees;
    private $extras;
    private $discount;
    private $amount;
    private $tax;
    private $amountExDiscount;
    private $amountPlusTax;

    private function getExtrasTotalAmount(): float
    {
        $total = 0;

        if ($this->extras) {

            if (is_a($this->extras, 'Illuminate\Support\Collection')) {
                $extras = $this->extras->pluck('quantity', 'pricing_extra_id')->toArray();
            }else {
                $extras = $this->extras;
            }

            foreach($extras as $extra => $qty)
            {
                $pricing_extra = PricingExtra::where('id', $extra)->first();
                if ($pricing_extra) {
                    $total += $pricing_extra->price * $qty;
                }
            }
        }

        return $total;
    }

    private function getAttendeesTotalAmount(): float
    {
        switch(strtolower($this->price->offer)) {
            case 'buy-two-get-one-free':
                if (count($this->attendees) >= 3) {
                    return $this->price->price * (count($this->attendees) - 1);
                }              
            default:
                return $this->price->price * count($this->attendees);
        }
    }    

    private function getTotalAmount(): float
    {
        $attendees_total = $this->getAttendeesTotalAmount();
        $extras_total = $this->getExtrasTotalAmount();

        return ($attendees_total + $extras_total) - $this->discount;
    }


    private function getTotalAmountExDiscount(): float
    {
        $attendees_total = $this->getAttendeesTotalAmount();
        $extras_total = $this->getExtrasTotalAmount();

        return ($attendees_total + $extras_total);
    }    

    private function getTotalTax(): float
    {
        return $this->getTotalAmount() * 0.2;

    }

    private function getTotalAmountPlusTax(): float
    {
        return $this->getTotalAmount() * 1.2;
    }

    private function getTotalDiscount($code): float
    {
        return $this->getTotalAmountExDiscount() * ($code->discount / 100);
    }

    public function execute(Registration $registration, PricingGroupPrice $price, array | Collection  $attendees, array | Collection $extras): array
    {
        $this->registration = $registration;
        $this->price = $price;
        $this->attendees = $attendees;
        $this->extras = $extras;

        $this->discount = 0;
        $this->amount = $this->getTotalAmount();
        $this->amountExDiscount = $this->getTotalAmountExDiscount();
        $this->amountPlusTax = $this->getTotalAmountPlusTax();
        $this->tax = $this->getTotalTax();

        if ($this->registration->promo)
        {
            $code = PromoCode::where('code', $this->registration->promo)->first();

            if ($code) 
            {
                $this->discount = $this->getTotalDiscount($code);
                $this->amount = $this->getTotalAmount();
                $this->amountExDiscount = $this->getTotalAmountExDiscount();
                $this->amountPlusTax = $this->getTotalAmountPlusTax();
                $this->tax = $this->getTotalTax();
            }
        }

        return [
            'price' => $this->price,
            'attendees' => $this->attendees,
            'extras' => $this->extras,
            'discount' => $this->discount,
            'amountExDiscount' => $this->amountExDiscount,
            'amount' => $this->amount,
            'tax' => $this->tax,
            'amountPlusTax' => $this->amountPlusTax,
        ];
    }    
}