<?php

namespace App\Http\Controllers\Assets;

use Illuminate\Http\Request;

use File;
use Image;
use Storage;

use App\Http\Controllers\Controller;

class AssetImageController extends Controller
{
    public function __invoke($filename, $width = 100, $height = 100)
    {        
        $thumb_path = storage_path('app/public/thumb-' . $width . '-' . $height . '-' . $filename);

        if (!is_numeric($width)) {
            abort(400, 'Width is not number');
        }

        if (!is_numeric($height)) {
            abort(400, 'Height is not number');
        }

        if ((int)$width > 2000) {
            $width = 2000;
        }
        
        if ((int)$height > 2000) {
            $height = 2000;
        }

        // Replace with a preg
        if (!preg_match('/^[A-Z0-9\-\_]+\.(jpg|jpeg|png|gif)$/i', $filename)) {
            abort(400, 'Invalid filename');
        }

        if (!Storage::disk('s3')->exists($filename)) {
            abort(404, 'Image not found');
        } 

        if (File::exists($thumb_path)) {
            return response()->file($thumb_path);
        } else {
            $img = Image::make(Storage::disk('s3')->url($filename));

            $img->fit($width, $height, function ($constraint) {
                $constraint->upsize();
            });

            $img->save($thumb_path);
    
            return $img->response();    
        }
    }
}
