<?php

namespace App\Http\Controllers\Page;

use Illuminate\Http\Request;
use Stripe\Stripe;
use Stripe\PaymentIntent;

use App\Models\Page;
use App\Models\PromoCode;
use App\Models\PricingExtra;

use App\Actions\Ecommerce\PriceCalculator;

use App\Http\Controllers\Controller;

class PageCheckoutPaymentIntentController extends Controller
{
    private $page;
    private $registration;
    private $price;
    private $discount;
    private $attendees;
    private $extras;
    private $amount;
    private $amountPlusTax;

    private function calculate()
    {
        $this->attendees = session()->get('attendees');
        $this->extras = session()->get('extras', []);
        $this->price = session()->get('price');
        $this->discount = 0;

        $result = (new PriceCalculator)->execute($this->registration, $this->price, $this->attendees, $this->extras);

        $this->amount = $result['amount'];
        $this->amountPlusTax = $result['amountPlusTax'];
        $this->discount = $result['discount'];

    }

    public function show(Request $request, Page $page)
    {
        $this->page = $page;
        $this->registration = session()->get('registration');

        if (!$this->registration) {
            return response()->json(['error' => 'Registration not found'], 404);
        }

        $this->calculate();

        // Set stripe api key
        Stripe::setApiKey(config('services.stripe.secret'));

        // Get stripe payment intent data
        $data = [
            'amount' => $this->amountPlusTax * 100,
            'currency' => 'gbp',
            'automatic_payment_methods' => [
                'enabled' => true,
            ],
            'receipt_email' => $this->registration->email,
        ];   

        // Add additional metadata to stripe payment intent
        $data['metadata']['event'] = $page->slug;
        $data['metadata']['registration'] = $this->registration->id;
        $data['metadata']['email'] = $this->registration->email;

        if ($this->registration->promo)
        {
            $data['metadata']['promo'] = $this->registration->promo;
        }

        // Create the intent
        $intent = PaymentIntent::create($data);

        // Return the intent secret
        return response()->json([
            'clientSecret' => $intent->client_secret,
        ]);
    }        
}