<?php

namespace App\Http\Controllers\Portal;

use Illuminate\Http\Request;

use Spatie\IcalendarGenerator\Components\Calendar;
use Spatie\IcalendarGenerator\Components\Event;

use App\Http\Controllers\Controller;
use App\Models\Page;
use App\Models\Programme;

class PortalCalendarDownloadController extends Controller
{
    public function __invoke(Page $page)
    {
        if (!$page->portal) {
            abort(404, 'Unable to find portal');
        }

        $user_events = auth()
            ->user()
            ->calendars()
            ->join('programmes', 'programmes.id', '=', 'calendars.programme_id')
            ->whereIn('programme_id', Programme::where('page_id', $page->id)->pluck('id')->toArray())
            ->orderBy('programmes.starts_at', 'ASC')
            ->get();  

        if (!$user_events->count() > 0) {
            abort(404, 'No events found');
        }

        $calendar_events = [];

        foreach($user_events as $user_event)
        {
            $calendar_events[] = Event::create($user_event->title)
                ->withoutTimezone()
                ->startsAt($user_event->programme->starts_at)
                ->endsAt($user_event->programme->ends_at);
        }

        $calendar = Calendar::create($page->title)
            ->event($calendar_events);

        return response($calendar->get())
            ->header('Content-Type', 'text/calendar')
            ->header('Content-Disposition', 'attachment; filename="calendar.ics"');

    }
}