<?php

namespace App\Http\Controllers\Portal;

use Illuminate\Http\Request;

use App\Http\Controllers\Controller;
use App\Http\Requests\Portal\PortalProfileRequest;

use App\Models\Page;

class PortalProfileController extends Controller
{
    public function show(Page $page)
    {
        if (!$page->portal) {
            abort(404, 'Unable to find portal');
        }

        $profile = auth()->user()->profile;

        return view('portal.profile', ['page' => $page, 'profile' => $profile]);
    }

    public function update(PortalProfileRequest $request, Page $page)
    {
        if (!$page->portal) {
            abort(404, 'Unable to find portal');
        }

        $validated = $request->validated();

        $filename = null;

        if ($request->hasFile('picture')) 
        {
            $filename = $request->file('picture')->storeAs(
                'profiles', auth()->user()->id . '.' . $request->file('picture')->extension(), 's3'
            );
        }

        auth()->user()->update([
            'forename' => $validated['forename'],
            'surname' => $validated['surname'],
            'portal' => $validated['portal'],
        ]);

        if (auth()->user()->profile) {
            auth()->user()->profile->update([
                'company' => $validated['company'],
                'position' => $validated['position'],
                'about' => $validated['about'],
                'twitter' => $validated['twitter'],
                'linkedin' => $validated['linkedin'],
                'website' => $validated['website'],
                'telephone' => $validated['telephone'],
                'mobile' => $validated['mobile'],
                'picture' => $filename,
            ]);
        }else {
            auth()->user()->profile()->create([
                'company' => $validated['company'],
                'position' => $validated['position'],
                'about' => $validated['about'],
                'twitter' => $validated['twitter'],
                'linkedin' => $validated['linkedin'],
                'website' => $validated['website'],
                'telephone' => $validated['telephone'],
                'mobile' => $validated['mobile'],
                'picture' => $filename,
            ]);
        }

        return redirect()->route('portal.page', ['page' => $page->slug])->with('status', 'Profile updated successfully.');
    }
}