<?php

namespace App\Http\Controllers\Stripe;

use Illuminate\Http\Request;
use Stripe\Stripe;
use Stripe\Webhook;

use App\Http\Controllers\Controller;
use App\Jobs\ProcessStripeWebhook;

class StripeWebhookController extends Controller
{
    public function __invoke(Request $request) 
    {
        // Set your Stripe API key
        Stripe::setApiKey(config('services.stripe.secret'));

        // Retrieve the webhook payload
        $payload = $request->getContent();

        // Verify the webhook signature
        try {
            $event = Webhook::constructEvent(
                $payload,
                $request->header('stripe-signature'),
                config('services.stripe.webhook')
            );
        } catch (\Exception $e) {
            return response('Webhook signature verification failed', 403);
        }

        // Handle the specific webhook event
        switch ($event->type) {
            case 'payment_intent.succeeded':
                // Handle successful payment
                ProcessStripeWebhook::dispatch($event, config('mail.default_to.address'));
                break;
            default:
                break;
        }

        return response('Webhook handled', 200);        

    }
}
