<?php

namespace App\Http\Livewire\Banners\Blocks;

use Livewire\Component;

class TextBlock extends Component
{
    public $component;
    public $element = 'h2';

    private function textSize()
    {
        switch(strtolower($this->component['size'])) {
            case 'medium': 
                return 'lg:text-xl text-sm';
            case 'large': 
                return 'lg:text-2xl text-base';
            case 'xlarge': 
                return 'lg:text-4xl text-xl';
            default: 
                return 'lg:text-base text-sm';
        }
    }

    private function textFont()
    {
        switch(strtolower($this->component['font'])) {
            case 'oswald':
                return 'font-altgothic';
            case 'ptserif':
                return 'font-serif';
            default: 
                return 'font-sans';
        }
    }

    private function colourText()
    {
        switch(strtolower($this->component['colour'])) {
            case 'white':
                return 'text-white';
            default: 
                return 'text-black';
        }
    }

    private function marginBottom()
    {
        switch($this->component['margin']) {
            case '2':
                return 'lg:mb-2 mb-0';
            case '4':
                return 'lg:mb-4 mb-1';
            case '8':
                return 'lg:mb-8 mb-2';
            default:
                return 'mb-0';
        }
    }

    private function elementType()
    {
        switch($this->component['element']){
            case 'h2': {
                return 'h2';
            }
            default:
                return 'p';
        }
    }

    public function mount($component)
    {
        $this->component = $component;
        $this->styles = [];
        if (isset($this->component['element'])) {
            $this->element = $this->elementType();
        }
        if (isset($this->component['size'])) {
            $this->styles[] = $this->textSize();
        }
        if (isset($this->component['font'])) {
            $this->styles[] = $this->textFont();
        }
        if (isset($this->component['colour'])) {
            $this->styles[] = $this->colourText();
        }
        if (isset($this->component['margin'])) {
            $this->styles[] = $this->marginBottom();
        }        
        $this->styles = implode(' ', $this->styles);
    }

    public function render()
    {
        return view('livewire.banners.blocks.text-block');
    }
}
