<?php

namespace App\Http\Livewire\Content\Common;

use Livewire\Component;

use Illuminate\Support\Facades\Mail;
use App\Mail\SendContactEmail;

class ContactModal extends Component
{
    public $open = false;

    public $forename;
    public $surname;
    public $email;
    public $company;
    public $jobtitle;
    public $country;
    public $subject;
    public $message;
    public $updates;

    protected $rules = [
        'forename' => ['required', 'string', 'max:100'],
        'surname' => ['required', 'string', 'max:100'],
        'email' => ['required', 'email', 'max:200'],
        'company' => ['required', 'string', 'max:100'],
        'jobtitle' => ['required', 'string', 'max:100'],
        'country' => ['required', 'string', 'max:100'],
        'subject' => ['required', 'string', 'max:100'],
        'message' => ['required', 'string', 'max:2000'],
    ];

    public function toggleModal()
    {
        $this->open = !$this->open;
    }

    public function submit()
    {
        $this->validate();

        $data = [
            'forename' => $this->forename,
            'surname' => $this->surname,
            'email' => $this->email,
            'company' => $this->company,
            'jobtitle' => $this->jobtitle,
            'country' => $this->country,
            'subject' => $this->subject,
            'message' => $this->message,
            'updates' => $this->updates ? 'Yes' : 'No',
        ];

        Mail::to(config('mail.default_to.address'), config('mail.default_to.name'))->send(new SendContactEmail(null, $data));

        $this->reset();

        $this->open = false;
    }

    public function render()
    {
        return view('livewire.content.common.contact-modal');
    }
}
