<?php

namespace App\Http\Livewire\Forms\Blocks;

use Livewire\Component;

use App\Models\PricingGroup;

use App\Mail\SendTableBookingContact;

use Mail;

class BookTableBlock extends Component
{
    public $page;
    public $fields;
    public $field;
    public $open = false;

    public $name;
    public $email;
    public $phone;
    public $company;
    public $message;

    protected $rules = [
        'name' => 'required',
        'email' => 'required|email',
        'phone' => 'nullable',
        'company' => 'required',
        'message' => 'nullable',
    ];

    public function mount($fields, $field, $page)
    {
        $this->fields = $fields;
        $this->field = $field;
        $this->page = $page;
    }

    public function toggleOpen()
    {
        $this->open = !$this->open;
    }

    public function submit()
    {
        $this->validate();

        Mail::to(config('mail.default_to.address'))->send(new SendTableBookingContact([
            'name' => $this->name,
            'email' => $this->email,
            'phone' => $this->phone,
            'company' => $this->company,
            'message' => $this->message,
        ], $this->page));

        $this->reset(['name', 'email', 'phone', 'company', 'message']);

        $this->toggleOpen();
    }

    public function render()
    {
        return view('livewire.forms.blocks.book-table-block');
    }    
}