<?php

namespace App\Http\Livewire\Layout\Blocks;

use Livewire\Component;

use Carbon\Carbon;
use Carbon\CarbonPeriod;

class ProgrammeBlock extends Component
{
    public $page;
    public $component;
    public $dates;
    public $selected = null;
    public $range = [];
    public $programmes;
    public $open = '';

    public function mount($page, $component)
    {
        $this->page = $page;
        $this->component = $component;
        $this->programmes = $this->page->programmes()->available()->orderBy('sort_order', 'ASC')->get();
        $this->dates = array_map(function($date) { return $date->format('Y-m-d');}, CarbonPeriod::create($this->page->starts_at->format('Y-m-d'), $this->page->ends_at->format('Y-m-d'))->toArray());
    }

    public function changeDate($date = null)
    {
        $this->selected = $date ? Carbon::parse($date) : null;

        if ($this->selected) {

            $this->range = [
                $this->selected,
                $this->selected->copy()->addHours(23)->addMinutes(59)->addSeconds(59)
            ];

            $this->programmes = $this
                ->page
                ->programmes()
                ->available()
                ->whereBetween('starts_at', $this->range)
                ->orderBy('sort_order', 'ASC')
                ->get();

        } else {
            $this->programmes = $this
                ->page
                ->programmes()
                ->available()
                ->orderBy('sort_order', 'ASC')                
                ->get();
        }

    }

    public function toggleOpen($id)
    {
        $this->open = $this->open === $id ? '' : $id;
    }

    public function render()
    {
        return view('livewire.layout.blocks.programme-block');
    }
}
