<?php

namespace App\Http\Livewire\Layout\Blocks;

use Livewire\Component;

use Cache;
use Log;
use Storage;

class RelatedArticlesBlock extends Component
{
    public $page;
    public $component;
    public $category;
    public $articles;
    public $images;
    public $error = false;
    public $errorMessage;    

    private function getApiUrl() {
        return "https://thetechcapital.com/wp-json/wp/v2/posts?categories={$this->category}&orderby=date&order=desc&per_page=4&_embed";
    }

    private function getArticles() {
        try {
            $url = $this->getApiUrl();
            return json_decode(file_get_contents($url));
        } catch (Exception $ex) {
            $this->error = true;
            $this->errorMessage = $ex;
        }
    }

    private function getCacheKey($key){
        return 'related-'. $key .'-' . $this->category;
    }

    private function extractImages()
    {
        try {
            $images = [];
            foreach ($this->articles as $article) {
                if (isset($article->_embedded->{'wp:featuredmedia'}[0]->source_url)) {
                    $url = $article->_embedded->{'wp:featuredmedia'}[0]->source_url;
                    $filename = basename($url);
                    if (!Storage::disk('s3')->exists($filename)) {
                        $path = storage_path('app/public/downloads' . $filename);
                        $download = file_get_contents($url);
                        if ($download) {
                            Storage::disk('s3')->put($filename, $download); 
                            $images[$article->id] = $filename;                            
                        }
                    }else {
                        $images[$article->id] = $filename;
                    }
                }
            }
        } catch (\Throwable $e) {
            Log::error($e->getMessage());
        }

        return $images;
    }


    public function mount($page, $component)
    {
        $this->page = $page;
        $this->component = $component;
        $this->category = $component['category'];

        if (!Cache::has($this->getCacheKey('articles'))){
            $this->articles = $this->getArticles();
            Cache::put($this->getCacheKey('articles'), $this->articles, now()->addMinutes(5));
        }else{
            $this->articles = Cache::get($this->getCacheKey('articles'));
        }

        if (!Cache::has($this->getCacheKey('images'))){
            $this->images = $this->extractImages();
            Cache::put($this->getCacheKey('images'), $this->images, now()->addMinutes(5));
        }else {
            $this->images = Cache::get($this->getCacheKey('images'));
        }
    }

    public function render()
    {
        return view('livewire.layout.blocks.related-articles-block');
    }
}
