<?php

namespace App\Http\Livewire\Portal\Chat;

use Livewire\Component;

use App\Models\Portal\Chat;
use App\Models\User;

class ChatBox extends Component
{
    public $page;
    public $selected;
    public $chats;
    public $message;
    public $target;

    protected $rules = [
        'message' => 'required|string|max:1000',
    ];

    public function loadChats()
    {
        $this->chats = Chat::where([
            ['page_id', '=', $this->page->id],
            ['from_user_id', '=', auth()->user()->id],
            ['to_user_id', '=', $this->selected]
        ])
        ->orWhere([
            ['page_id', '=', $this->page->id],
            ['from_user_id', '=', $this->selected],
            ['to_user_id', '=', auth()->user()->id]
        ])
        ->orderBy('created_at', 'desc')
        ->get();             
    }

    public function send()
    {
        $this->validate();

        Chat::create([
            'page_id' => $this->page->id,
            'from_user_id' => auth()->user()->id,
            'to_user_id' => $this->selected,
            'message' => $this->message,
        ]);
        $this->reset('message');
        $this->loadChats();
    }

    public function mount($page)
    {
        $this->page = $page;

        $this->selected = request()->query('selected', null);

        if ($this->selected){
            $this->target = User::where('id', $this->selected)->first();
        }

        $this->loadChats();
    }

    public function render()
    {
        return view('livewire.portal.chat.chat-box');
    }
}
