<?php

namespace App\Http\Livewire\Portal\Dialogs;

use Livewire\Component;

use App\Models\Attendee;
use App\Models\User;
use App\Models\Portal\Connection;

class DialogUser extends Component
{
    public $page;
    public $attendee;
    public $user;
    public $profile;
    public $same = false;
    public $open = false;
    public $message = null;

    protected $rules = [
        'message' => 'nullable|string|max:1000'
    ];

    protected $listeners = [
        'open-user-dialog' => 'openUserDialog', 
        'close-user-dialog' => 'closeUserDialog'
    ];

    public function openUserDialog($selected)
    {
        $this->open = true;
        $this->user = User::where('id', $selected)->first();
        if ($this->user) {
            $this->attendee = Attendee::where('email', $this->user->email)->first();
            if ($this->user->profile) {
                $this->profile = $this->user->profile;
            }
        }
    }

    public function closeUserDialog()
    {
        $this->open = false;
        $this->attendee = null;
        $this->user = null;
        $this->profile = null;
    }

    public function send()
    {
        $this->validate();

        $connection = Connection::firstOrCreate([
            'page_id' => $this->page->id,
            'from_user_id' => auth()->user()->id,
            'to_user_id' => $this->user->id,
        ], [
            'message' => $this->message
        ]);

        if ($connection->wasRecentlyCreated) {
            return redirect()->route('portal.attendees', ['page' => $this->page->slug])->with('status', 'Connection request sent');    
        } else {
            return redirect()->route('portal.attendees', ['page' => $this->page->slug])->with('status', 'Connection request already sent and pending');
        }
    }

    public function mount($page)
    {
        $this->page = $page;
    }

    public function render()
    {
        return view('livewire.portal.dialogs.dialog-user');
    }
}
