<?php

namespace App\Http\Livewire\Portal\Lists;

use Livewire\Component;

use Carbon\Carbon;
use Carbon\CarbonPeriod;

use App\Models\Page;

class ListProgrammes extends Component
{
    public $page;
    public $dates;
    public $selected = null;
    public $range = [];
    public $programmes;
    public $calendars;
    public $open = '';

    protected $listeners = [
        'refresh-programme-calendars' => 'loadUserCalendars'
    ];

    public function loadUserCalendars()
    {
        $this->calendars = auth()
            ->user()
            ->calendars()
            ->whereIn('programme_id', $this->page->programmes()->pluck('id')->toArray())
            ->get();
    }

    public function mount(Page $page)
    {
        $this->page = $page;
        $this->programmes = $this->page->programmes()->available()->orderBy('sort_order', 'ASC')->get();
        $this->dates = array_map(function($date) { return $date->format('Y-m-d');}, CarbonPeriod::create($this->page->starts_at->format('Y-m-d'), $this->page->ends_at->format('Y-m-d'))->toArray());

        if (in_array(now()->format('Y-m-d'), $this->dates)) {
            $this->selected = now()->format('Y-m-d');
        }

        $this->loadUserCalendars();
    }
    
    public function changeDate($date = null)
    {
        $this->selected = $date ? Carbon::parse($date) : null;

        if ($this->selected) {

            $this->range = [
                $this->selected,
                $this->selected->copy()->addHours(23)->addMinutes(59)->addSeconds(59)
            ];

            $this->programmes = $this
                ->page
                ->programmes()
                ->available()
                ->whereBetween('starts_at', $this->range)
                ->orderBy('starts_at', 'ASC')
                ->get();

        } else {
            $this->programmes = $this
                ->page
                ->programmes()
                ->available()
                ->orderBy('starts_at', 'ASC')                
                ->get();
        }
    }

    public function toggleCalendar($id)
    {
        $calendar = auth()->user()->calendars()->where('programme_id', $id)->first();

        if (!$calendar) {
            auth()->user()->calendars()->create([
                'programme_id' => $id
            ]);
        } else {
            $calendar->delete();
        }

        $this->loadUserCalendars();

        $this->emit('refresh-calendar-users');
    }

    public function toggleOpen($id)
    {
        $this->open = $this->open === $id ? '' : $id;
    }

    public function render()
    {
        return view('livewire.portal.lists.list-programmes');
    }
}
