<?php

namespace App\Listeners;

use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Support\Facades\Mail;

use App\Events\RegistrationUpdatedEvent;
use App\Actions\Fortify\CreateNewUser;
use App\Mail\SendPortalRegistrationEmail;
use App\Models\User;

class RegistrationCreatedListener
{
    /**
     * Create the event listener.
     *
     * @return void
     */
    public function __construct()
    {
        //
    }

    /**
     * Handle the event.
     *
     * @param  object  $event
     * @return void
     */
    public function handle(RegistrationUpdatedEvent $event)
    {
        $registration = $event->registration;

        if ($registration->portal && ($registration->status === 1 || $registration->status === 2)) {

            foreach($registration->attendees()->get() as $attendee) {
                $user = User::where('email', $attendee->email)->first();

                if (!$user) {
                    $password = Str::random(12);

                    $user = (new CreateNewUser)->create([
                        'forename' => $attendee->forename,
                        'surname' => $attendee->surname,
                        'email' => $registration->email,
                        'password' => $password,
                        'password_confirmation' => $password,
                        'portal' => $registration->portal,
                    ]);

                    if ($user) {
                        Mail::to($attendee->email)
                            ->send(new SendPortalRegistrationEmail($registration, $user, $password));
                    }
                }
            }
        }

    }
}
