<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

use Illuminate\Support\Facades\Auth;

class Page extends Model
{
    use HasFactory;

    protected $casts = [
        'starts_at' => 'datetime',
        'ends_at' => 'datetime'
    ];

    protected $fillable = [
        'name', 'slug'
    ];

    public function categories()
    {
        return $this->hasMany(Category::class);
    }

    public function menuitems()
    {
        return $this->hasMany(MenuItem::class);
    }

    public function programmes()
    {
        return $this->hasMany(Programme::class);
    }

    public function banners()
    {
        return $this->hasMany(Banner::class);
    }

    public function expectations()
    {
        return $this->hasMany(Expectation::class);
    }

    public function galleries()
    {
        return $this->hasMany(Gallery::class);
    }
    
    public function speakers()
    {
        return $this->hasMany(Speaker::class);
    }

    public function judges()
    {
        return $this->hasMany(Judge::class);
    }

    public function sponsors()
    {
        return $this->hasMany(Sponsor::class);
    }

    public function registrations()
    {
        return $this->hasMany(Registration::class);
    }

    public function hotels()
    {
        return $this->hasMany(Hotel::class);
    }

    public function travels()
    {
        return $this->hasMany(Travel::class);
    }    

    public function todos()
    {
        return $this->hasMany(ToDo::class);
    }

    public function pricing_group()
    {
        return $this->hasOne(PricingGroup::class);
    }

    public function pricing_extras()
    {
        return $this->hasMany(PricingExtra::class);
    }

    public function promo_codes()
    {
        return $this->hasMany(PromoCode::class);
    }

    public function testimonials()
    {
        return $this->hasMany(Testimonial::class);
    }

    public function share_tags()
    {
        return $this->hasMany(ShareTag::class);
    }

    public function scopeAvailable($query)
    {
        return $query->where([
            ['status', '=', 1]
        ]);
    }

    /**
     * Retrieve the model for a bound value.
     *
     * @param  mixed  $value
     * @param  string|null  $field
     * @return \Illuminate\Database\Eloquent\Model|null
     */
    public function resolveRouteBinding($value, $field = null)
    {
        if (Auth::check()) {
            return $this->where('slug', $value)->firstOrFail();
        } else {
            return $this->where('slug', $value)->available()->firstOrFail();
        }
    }
}
