<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

use App\Events\RegistrationUpdatedEvent;

class Registration extends Model
{
    use HasFactory;

    protected $casts = [
        'extra' => 'array'
    ];

    protected $fillable = [
        'page_id', 'pricing_group_price_id', 'country_id', 'job_function_id', 'company_type_id', 
        'title', 'forename', 'surname', 'email', 'phone', 'company',
        'job_role', 'newsletter', 'reception', 'sponsorship', 'promo', 'extra', 'portal'
    ];

    protected $dispatchedEvents = [
        'updated' => RegistrationUpdatedEvent::class,
    ];

    public function page()
    {
        return $this->belongsTo(Page::class);
    }

    public function pricing_group_price()
    {
        return $this->belongsTo(PricingGroupPrice::class);
    }

    public function attendees()
    {
        return $this->hasMany(Attendee::class);
    }

    public function extras()
    {
        return $this->hasMany(Extra::class);
    }

    public function transactions()
    {
        return $this->hasMany(Transaction::class);
    }

    public function company_type()
    {
        return $this->belongsTo(CompanyType::class);
    }

    public function job_function()
    {
        return $this->belongsTo(JobFunction::class);
    }

    public function country()
    {
        return $this->belongsTo(Country::class);
    }
}
