<?php

namespace App\Nova\Actions;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Support\Collection;
use Laravel\Nova\Actions\Action;
use Laravel\Nova\Fields\ActionFields;
use PhpOffice\PhpSpreadsheet\Reader\Csv;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx;

use App\Jobs\PurgeData;

use Log;

class AttendeesDownloadAction extends Action
{
    use InteractsWithQueue, Queueable;

    private function createCSV($identifier, $attendees)
    {
        try {
            $path = storage_path('app/downloads/data/' . $identifier . '.csv');

            $headers = [
                'id', 'page', 'registration', 'registration_forename', 
                'registration_surname', 'registration_email', 'forename', 
                'surname', 'email'
            ];

            $file = fopen($path, 'w');

            if ($file) {

                fputcsv($file, $headers, ",", '"');

                foreach($attendees as $attendee)
                {
                    $row = [
                        'id' => $attendee->id,
                        'page' => $attendee->registration->page->title,
                        'registration' => $attendee->registration->id,
                        'registration_forename' => $attendee->registration->forename,
                        'registration_surname' => $attendee->registration->surname,
                        'registration_email' => $attendee->registration->email,
                        'forename' => $attendee->forename,
                        'surname' => $attendee->surname,
                        'email' => $attendee->email
                    ];
                        
                    fputcsv($file, $row, ",", '"');
                }
            }

            fclose($file);     
            
            return true;
        } catch (Exception $ex) {
            Log::error(ex);
        }
    }

    private function createXLSX($identifier)
    {
        try {
            $paths = [
                'csv' => storage_path('/app/downloads/data/'. $identifier .'.csv'),
                'xlsx' => storage_path('/app/downloads/data/'. $identifier .'.xlsx')
            ];
            $reader = new Csv();
            $encoding = Csv::guessEncoding($paths['csv']);
            $reader->setInputEncoding($encoding);
            $reader->setDelimiter(',');
            $reader->setEnclosure('"');
            $spreadsheet = $reader->load($paths['csv']);

            $writer = new Xlsx($spreadsheet);
            $writer->save($paths['xlsx']);
            
            return true;
        } catch (Exception $ex) {
            Log::error(ex);
        }
    }    

    /**
     * Perform the action on the given models.
     *
     * @param  \Laravel\Nova\Fields\ActionFields  $fields
     * @param  \Illuminate\Support\Collection  $models
     * @return mixed
     */
    public function handle(ActionFields $fields, Collection $models)
    {
        if (!$models) {
            return Action::danger('No attendees to download');
        }

        $identifier = uniqid();

        $created = $this->createCSV($identifier, $models);

        if (!$created) {
            return Action::danger('No CSV was created');
        }

        $converted = $this->createXLSX($identifier);

        if (!$converted) {
            return Action::danger('No XLSX was created');
        }

        PurgeData::dispatch()->delay(now()->addMinutes(10));

        return Action::download(config('app.url') . '/downloads/' . $identifier, $identifier . '.xlsx');
    }

    /**
     * Get the fields available on the action.
     *
     * @return array
     */
    public function fields()
    {
        return [];
    }
}
