<?php

namespace App\Nova\Actions;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Support\Collection;
use Laravel\Nova\Actions\Action;
use Laravel\Nova\Fields\ActionFields;
use Illuminate\Support\Str;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Hash;

use App\Models\User;
use App\Actions\Fortify\CreateNewUser;
use App\Mail\SendPortalRegistrationEmail;

class CreatePortalUserFromRegistrationAction extends Action
{
    use InteractsWithQueue, Queueable;

    /**
     * Perform the action on the given models.
     *
     * @param  \Laravel\Nova\Fields\ActionFields  $fields
     * @param  \Illuminate\Support\Collection  $models
     * @return mixed
     */
    public function handle(ActionFields $fields, Collection $models)
    {
        // Iterate each registration 
        foreach ($models as $model)
        {
            // Check if the user already exists
            $user = User::where('email', strtolower($model->email))->first();

            // Create password
            $password = Str::random(12);

            // If the user doesnt exist then create a new user
            if (!$user) 
            {
                $user = (new CreateNewUser)->create([
                    'forename' => $model->forename,
                    'surname' => $model->surname,
                    'email' => strtolower($model->email),
                    'password' => $password,
                    'password_confirmation' => $password,
                    'portal' => false,
                ]);
            } else {
                $user->password = Hash::make($password);
                $user->portal = false;
                $user->save();
            }

            // If the user was created or already exists then send the portal registration email
            if ($user)
            {
                Mail::to($model->email)
                    ->send(new SendPortalRegistrationEmail($model, $user, $password));
            }

            $model->portal = true;
            $model->save();
        }

        return Action::message('Portal users created!');

    }

    /**
     * Get the fields available on the action.
     *
     * @return array
     */
    public function fields()
    {
        return [];
    }


}