<?php

namespace App\Nova;

use Illuminate\Http\Request;
use Laravel\Nova\Fields\ID;
use Laravel\Nova\Fields\Text;
use Laravel\Nova\Fields\Textarea;
use Laravel\Nova\Fields\Select;
use Laravel\Nova\Fields\BelongsTo;
use Laravel\Nova\Fields\Image;
use Laravel\Nova\Http\Requests\NovaRequest;

use OptimistDigital\NovaSortable\Traits\HasSortableRows;

use App\Nova\Filters\PageFilter;

class Category extends Resource
{
    use HasSortableRows;

    /**
     * The number of resources to show per page via relationships.
     *
     * @var int
     */
    public static $perPageViaRelationship = 50;

    /**
     * The group in which this resource belongs to.
     */
    public static $group = 'Event Content';

    /**
     * The model the resource corresponds to.
     *
     * @var string
     */
    public static $model = \App\Models\Category::class;

    /**
     * The single value that should be used to represent the resource when being displayed.
     *
     * @var string
     */
    public static $title = 'name';

    /**
     * The columns that should be searched.
     *
     * @var array
     */
    public static $search = [
        'id','name','content'
    ];

    /**
     * Get the fields displayed by the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function fields(Request $request)
    {
        return [
            ID::make(__('ID'), 'id')->sortable(),
            BelongsTo::make('Page'),
            Text::make(__('Name'), 'name')
                ->rules('required', 'max:100'),
            Text::make(__('Group'), 'group')
                ->rules('nullable', 'max:50'),
            Textarea::make(__('Content'), 'content')
                ->rules('required'),
            Textarea::make(__('Criteria'), 'criteria')
                ->rules('nullable'),
            Text::make(__('Caption'), 'caption')
                ->hideFromIndex()
                ->nullable()
                ->rules('nullable', 'max:200'),       
            Text::make(__('URL'), 'url')
                ->hideFromIndex()
                ->nullable()
                ->rules('nullable', 'max:200'),                
            Image::make(__('Filename'), 'filename')
                ->disk('s3')
                ->nullable()
                ->creationRules('nullable', 'mimes:jpg,png,gif,svg')
                ->updateRules('nullable','mimes:jpg,png,gif,svg'),                             
            Select::make(__('Status'), 'status')
                ->options([
                    0 => 'Inactive', 
                    1 => 'Active'
                ])
                ->displayUsingLabels()
                ->rules('required')        
        ];
    }

    /**
     * Get the cards available for the request.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function cards(Request $request)
    {
        return [];
    }

    /**
     * Get the filters available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function filters(Request $request)
    {
        return [
            new PageFilter
        ];
    }

    /**
     * Get the lenses available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function lenses(Request $request)
    {
        return [];
    }

    /**
     * Get the actions available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function actions(Request $request)
    {
        return [];
    }
}
