<?php

namespace App\Nova;

use Illuminate\Http\Request;
use Laravel\Nova\Fields\ID;
use Laravel\Nova\Fields\Text;
use Laravel\Nova\Fields\Select;
use Laravel\Nova\Fields\Image;
use Laravel\Nova\Fields\DateTime;
use Laravel\Nova\Http\Requests\NovaRequest;

use App\Nova\Filters\ActiveEventFilter;

class Event extends Resource
{
    /**
     * The model the resource corresponds to.
     *
     * @var string
     */
    public static $model = \App\Models\Event::class;

    /**
     * The group in which this resource belongs to.
     */
    public static $group = 'Events & Pages';

    /**
     * The single value that should be used to represent the resource when being displayed.
     *
     * @var string
     */
    public static $title = 'name';

    /**
     * The columns that should be searched.
     *
     * @var array
     */
    public static $search = [
        'id', 'name', 'location'
    ];

    /**
     * Get the fields displayed by the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function fields(Request $request)
    {
        return [
            ID::make(__('ID'), 'id')->sortable(),
            Text::make(__('Name'), 'name')->rules('required', 'max:100'),
            Select::make(__('Type'), 'type')
                ->options([
                    'internal' => 'Internal',
                    'external' => 'External'
                ])
                ->displayUsingLabels()
                ->rules('required'),
            DateTime::make(__('Starts At'), 'starts_at')->rules('required'),
            DateTime::make(__('Ends At'), 'ends_at')->rules('required'),        
            Text::make(__('Location'), 'location')->rules('required', 'max:100'),
            Text::make(__('URL'), 'url')->rules('required', 'max:1000'),
            Select::make(__('Target'), 'target')
                ->options([
                    '_blank' => 'New Window',
                    '_self' => 'Same Window'
                ])
                ->hideFromIndex()
                ->rules('required'),
            Image::make(__('Thumbnail'), 'filename')
                ->hideFromIndex()
                ->disk('s3')
                ->creationRules('required', 'mimes:jpg,png,gif')  
                ->updateRules('nullable', 'mimes:jpg,png,gif'),     
            Image::make(__('Logo'), 'logo')
                ->hideFromIndex()
                ->disk('s3')
                ->nullable()
                ->rules('nullable', 'mimes:jpg,png,gif'),
            Select::make(__('Status'), 'status')
                ->options([
                    0 => 'Inactive', 
                    1 => 'Active',
                ])
                ->displayUsingLabels()
                ->rules('required')    
        ];
    }

    /**
     * Get the cards available for the request.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function cards(Request $request)
    {
        return [];
    }

    /**
     * Get the filters available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function filters(Request $request)
    {
        return [
            new ActiveEventFilter
        ];
    }

    /**
     * Get the lenses available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function lenses(Request $request)
    {
        return [];
    }

    /**
     * Get the actions available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function actions(Request $request)
    {
        return [];
    }
}
