<?php

namespace App\Nova;

use Illuminate\Http\Request;
use Laravel\Nova\Fields\ID;
use Laravel\Nova\Fields\Text;
use Laravel\Nova\Fields\Select;
use Laravel\Nova\Fields\Boolean;
use Laravel\Nova\Panel;
use Techevents\FormFields\FormFields;

use Laravel\Nova\Http\Requests\NovaRequest;

use App\Nova\Actions\FormCopyAction;

class Form extends Resource
{
    /**
     * The model the resource corresponds to.
     *
     * @var string
     */
    public static $model = \App\Models\Form::class;

    /**
     * The group in which this resource belongs to.
     */
    public static $group = 'Registrations';

    /**
     * The single value that should be used to represent the resource when being displayed.
     *
     * @var string
     */
    public static $title = 'name';

    /**
     * The columns that should be searched.
     *
     * @var array
     */
    public static $search = [
        'id',
    ];

    /**
     * Get the fields displayed by the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function fields(Request $request)
    {
        return [
            ID::make(__('ID'), 'id')->sortable(),
            Text::make(__('Name'), 'name')->rules('required', 'max:100'),
            Text::make(__('Heading'), 'heading')->rules('required', 'max:200'),
            Select::make(__('Type'), 'type')->options([
                'email' => 'Email',
                'registration' => 'Registration',
            ])->rules('required'),
            new Panel('Emails', $this->emailSettings()),
            new Panel('Submission', $this->submissionSettings()),
            new Panel('Fields', $this->formFields()),
        ];
    }

    protected function emailSettings(){
        return [
            Text::make(__('Subject'), 'subject')->rules('nullable', 'max:200'),
            Text::make(__('To'), 'to')->rules('nullable', 'max:1000'),
            Text::make(__('CC'), 'cc')->rules('nullable', 'max:1000'),
        ];
    }

    protected function submissionSettings(){
        return [
            Text::make(__('Url'), 'url')->rules('required', 'max:200'),
        ];
    }

    protected function formFields(){
        return [
            FormFields::make(__('Fields'), 'fields')->stacked()->hideFromIndex()->hideFromDetail(),
        ];
    }

    /**
     * Get the cards available for the request.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function cards(Request $request)
    {
        return [];
    }

    /**
     * Get the filters available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function filters(Request $request)
    {
        return [];
    }

    /**
     * Get the lenses available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function lenses(Request $request)
    {
        return [];
    }

    /**
     * Get the actions available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function actions(Request $request)
    {
        return [
            new FormCopyAction,
        ];
    }
}
