<?php

namespace App\Nova;

use Illuminate\Http\Request;
use Laravel\Nova\Fields\ID;
use Laravel\Nova\Fields\Text;
use Laravel\Nova\Fields\Select;
use Laravel\Nova\Panel;

use Laravel\Nova\Http\Requests\NovaRequest;

use Techevents\PageLayout\PageLayout;

class Homepage extends Resource
{
    /**
     * The model the resource corresponds to.
     *
     * @var string
     */
    public static $model = \App\Models\Homepage::class;

    /**
     * The group in which this resource belongs to.
     */
    public static $group = 'Content';

    /**
     * The single value that should be used to represent the resource when being displayed.
     *
     * @var string
     */
    public static $title = 'name';

    /**
     * The columns that should be searched.
     *
     * @var array
     */
    public static $search = [
        'id', 'name', 'title', 'description'
    ];

    /**
     * Get the fields displayed by the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function fields(Request $request)
    {
        return [
            ID::make(__('ID'), 'id')
                ->hideFromIndex(),            
            Text::make(__('Name'), 'name')
                ->rules('required', 'max:200'),       
            Text::make(__('Meta Title'), 'title')
                ->hideFromIndex()
                ->rules('required', 'max:200'),  
            Text::make(__('Meta Description'), 'description')
                ->hideFromIndex()
                ->rules('required', 'max:400'),        
            Select::make(__('Status'), 'status')
                ->options([
                    0 => 'Inactive', 
                    1 => 'Active'
                ])
                ->displayUsingLabels()
                ->rules('required'),  
            new Panel('Layout', $this->layoutFields())   
        ];
    }

    protected function layoutFields()
    {
        return [
            PageLayout::make(__('Layout'), 'layout')
                ->withMeta(['settings' => ['blocks' => 'homepage']])
                ->stacked()
                ->hideFromIndex()
                ->hideFromDetail(),            
        ];
    }

    /**
     * Get the cards available for the request.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function cards(Request $request)
    {
        return [];
    }

    /**
     * Get the filters available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function filters(Request $request)
    {
        return [];
    }

    /**
     * Get the lenses available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function lenses(Request $request)
    {
        return [];
    }

    /**
     * Get the actions available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function actions(Request $request)
    {
        return [];
    }
}
