<?php

namespace App\Nova;

use Illuminate\Http\Request;
use Laravel\Nova\Fields\ID;
use Laravel\Nova\Fields\Text;
use Laravel\Nova\Fields\Markdown;
use Laravel\Nova\Fields\BelongsTo;
use Laravel\Nova\Fields\Image;
use Laravel\Nova\Fields\Select;
use Laravel\Nova\Http\Requests\NovaRequest;

use App\Nova\Filters\PageFilter;

class Hotel extends Resource
{
    /**
     * The model the resource corresponds to.
     *
     * @var string
     */
    public static $model = \App\Models\Hotel::class;

    /**
     * The group in which this resource belongs to.
     */
    public static $group = 'Event Content';

    /**
     * The single value that should be used to represent the resource when being displayed.
     *
     * @var string
     */
    public static $title = 'name';

    /**
     * The columns that should be searched.
     *
     * @var array
     */
    public static $search = [
        'id','name', 'address', 'description'
    ];

    /**
     * Get the fields displayed by the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function fields(Request $request)
    {
        return [
            ID::make(__('ID'), 'id')->sortable(),
            BelongsTo::make('Page'),
            Text::make(__('Name'), 'name')->rules('required', 'max:100'),
            Text::make(__('Address'), 'address')->rules('required', 'max:1000'),
            Text::make(__('Map'), 'map')
                ->hideFromIndex()
                ->rules('nullable', 'max:200'),
            Markdown::make(__('Description'), 'description')->rules('required'),
            Image::make(__('Filename'), 'filename')
                ->disk('s3')
                ->creationRules('required', 'mimes:jpg,png,gif')
                ->updateRules('mimes:jpg,png,gif'),                 
            Text::make(__('Website'), 'website')
                ->hideFromIndex()
                ->rules('nullable', 'url', 'max:200'),           
            Select::make(__('Status'), 'status')
                ->options([
                    0 => 'Inactive', 
                    1 => 'Active'
                ])
                ->displayUsingLabels()
                ->rules('required')                 
        ];
    }

    /**
     * Get the cards available for the request.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function cards(Request $request)
    {
        return [];
    }

    /**
     * Get the filters available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function filters(Request $request)
    {
        return [
            new PageFilter
        ];
    }

    /**
     * Get the lenses available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function lenses(Request $request)
    {
        return [];
    }

    /**
     * Get the actions available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function actions(Request $request)
    {
        return [];
    }
}
