<?php

namespace App\Nova;

use Illuminate\Http\Request;
use Laravel\Nova\Fields\ID;
use Laravel\Nova\Fields\Text;
use Laravel\Nova\Fields\BelongsTo;
use Laravel\Nova\Fields\Select;
use Laravel\Nova\Fields\Boolean;
use Laravel\Nova\Fields\Markdown;
use Laravel\Nova\Http\Requests\NovaRequest;

class PricingGroupPrice extends Resource
{
    /**
     * The model the resource corresponds to.
     *
     * @var string
     */
    public static $model = \App\Models\PricingGroupPrice::class;

    /**
     * The group in which this resource belongs to.
     */
    public static $group = 'Event Pricing';

    /**
     * Get the value that should be displayed to represent the resource.
     *
     * @return string
     */
    public function title()
    {
        return $this->pricing_group->name . ' (' . $this->name . ')';
    }

    /**
     * The columns that should be searched.
     *
     * @var array
     */
    public static $search = [
        'id','name'
    ];

    /**
     * Get the fields displayed by the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function fields(Request $request)
    {
        return [
            ID::make(__('ID'), 'id')->sortable(),
            BelongsTo::make('Pricing Group'),
            Text::make(__('Name'), 'name')->rules('required', 'max:100'),
            Text::make(__('Text'), 'text')->rules('nullable', 'max:100'),
            Markdown::make(__('Description'), 'description')->rules('nullable'),
            Text::make(__('Price'), 'price')->rules('numeric', 'required'),
            Boolean::make(__('VAT Label'), 'vat'),
            Select::make(__('Offer'), 'offer')->options([
                '' => 'No Offer',
                'buy-two-get-one-free' => 'Buy Two Get One Free',
            ])->displayUsingLabels()->rules('nullable'),
            Select::make(__('Status'), 'status')->options([
                0 => 'Inactive',
                1 => 'Active',
            ])->displayUsingLabels()->rules('required'),
        ];
    }

    /**
     * Get the cards available for the request.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function cards(Request $request)
    {
        return [];
    }

    /**
     * Get the filters available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function filters(Request $request)
    {
        return [];
    }

    /**
     * Get the lenses available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function lenses(Request $request)
    {
        return [];
    }

    /**
     * Get the actions available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function actions(Request $request)
    {
        return [];
    }
}
