<?php

namespace App\Nova;

use Illuminate\Http\Request;
use Laravel\Nova\Fields\ID;
use Laravel\Nova\Fields\BelongsTo;
use Laravel\Nova\Fields\Text;
use Laravel\Nova\Fields\Textarea;
use Laravel\Nova\Fields\Image;
use Laravel\Nova\Http\Requests\NovaRequest;

class Profile extends Resource
{
    /**
     * The model the resource corresponds to.
     *
     * @var string
     */
    public static $model = \App\Models\Portal\Profile::class;

    /**
     * The group in which this resource belongs to.
     */
    public static $group = 'Portal';

    /**
     * Get the value that should be displayed to represent the resource.
     *
     * @return string
     */
    public function title()
    {
        return $this->user->forename . ' ' . $this->user->surname;
    }

    /**
     * The columns that should be searched.
     *
     * @var array
     */
    public static $search = [
        'id',
    ];

    /**
     * Get the fields displayed by the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function fields(Request $request)
    {
        return [
            ID::make(__('ID'), 'id')->sortable(),
            BelongsTo::make('User'),
            Text::make(__('Company'), 'company')->rules('nullable', 'max:100'),
            Text::make(__('Position'), 'position')->rules('nullable', 'max:100'),
            Textarea::make(__('About'), 'about')->rules('nullable'),
            Text::make(__('Twitter'), 'twitter')->rules('nullable', 'url', 'max:200'),
            Text::make(__('LinkedIn'), 'linkedin')->rules('nullable', 'url', 'max:200'),
            Text::make(__('Website'), 'website')->rules('nullable', 'url', 'max:200'),
            Text::make(__('Telephone'), 'telephone')->rules('nullable', 'max:30'),
            Text::make(__('Mobile'), 'mobile')->rules('nullable', 'max:30'),
            Image::make(__('Picture'), 'picture')->disk('s3')->path('profiles')->rules('nullable', 'image', 'max:1024'),
        ];
    }

    /**
     * Get the cards available for the request.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function cards(Request $request)
    {
        return [];
    }

    /**
     * Get the filters available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function filters(Request $request)
    {
        return [];
    }

    /**
     * Get the lenses available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function lenses(Request $request)
    {
        return [];
    }

    /**
     * Get the actions available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function actions(Request $request)
    {
        return [];
    }
}
