<?php

namespace App\Nova;

use Illuminate\Http\Request;
use Laravel\Nova\Fields\ID;
use Laravel\Nova\Fields\Text;
use Laravel\Nova\Fields\Textarea;
use Laravel\Nova\Fields\DateTime;
use Laravel\Nova\Fields\Select;
use Laravel\Nova\Fields\BelongsTo;
use Laravel\Nova\Fields\BelongsToMany;

use Laravel\Nova\Http\Requests\NovaRequest;

use OptimistDigital\NovaSortable\Traits\HasSortableRows;

use App\Nova\Filters\PageFilter;

class Programme extends Resource
{
    use HasSortableRows;

    /**
     * The model the resource corresponds to.
     *
     * @var string
     */
    public static $model = \App\Models\Programme::class;

    /**
     * The number of resources to show per page via relationships.
     *
     * @var int
     */
    public static $perPageViaRelationship = 60;

    /**
     * The group in which this resource belongs to.
     */
    public static $group = 'Event Content';

    /**
     * Get the value that should be displayed to represent the resource.
     *
     * @return string
     */
    public function title()
    {
        return $this->title . ' (' . $this->starts_at->format('d/m/Y H:i') . ' - ' . $this->ends_at->format('H:i') . ')';
    }

    /**
     * The columns that should be searched.
     *
     * @var array
     */
    public static $search = [
        'id', 'title', 'description'
    ];

    /**
     * Get the fields displayed by the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function fields(Request $request)
    {
        return [
            ID::make(__('ID'), 'id')->sortable(),
            BelongsTo::make('Page'),
            Text::make(__('Title'), 'title')
                ->rules('required', 'max:1000'),
            Textarea::make(__('Description'), 'description')
                ->rules('nullable'),
            Select::make(__('Track'), 'track')
                ->options([
                    '' => 'None',
                    'track-1' => 'Track 1',
                    'track-2' => 'Track 2',
                ])
                ->rules('nullable', 'max:20'),
            DateTime::make(__('Starts At'), 'starts_at')
                ->sortable()
                ->rules('required'),
            DateTime::make(__('Ends At'), 'ends_at')
                ->sortable()
                ->rules('required'),
            Select::make(__('Status'), 'status')
                ->options([
                    0 => 'Inactive', 
                    1 => 'Active'
                ])
                ->displayUsingLabels()
                ->rules('required'),
            BelongsToMany::make('Speakers')->searchable(),
        ];
    }

    /**
     * Get the cards available for the request.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function cards(Request $request)
    {
        return [];
    }

    /**
     * Get the filters available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function filters(Request $request)
    {
        return [
            new PageFilter
        ];
    }

    /**
     * Get the lenses available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function lenses(Request $request)
    {
        return [];
    }

    /**
     * Get the actions available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function actions(Request $request)
    {
        return [];
    }
}
