<?php

namespace App\Nova;

use Illuminate\Http\Request;
use Laravel\Nova\Fields\ID;
use Laravel\Nova\Http\Requests\NovaRequest;
use Laravel\Nova\Panel;

use Laravel\Nova\Fields\Text;
use Laravel\Nova\Fields\Textarea;
use Laravel\Nova\Fields\Image;
use Laravel\Nova\Fields\Select;
use Laravel\Nova\Fields\BelongsTo;

class ShareTag extends Resource
{
    /**
     * The model the resource corresponds to.
     *
     * @var string
     */
    public static $model = \App\Models\ShareTag::class;

    /**
     * The group in which this resource belongs to.
     */
    public static $group = 'Content';

    /**
     * The single value that should be used to represent the resource when being displayed.
     *
     * @var string
     */
    public static $title = 'id';

    /**
     * The columns that should be searched.
     *
     * @var array
     */
    public static $search = [
        'id',
    ];

    /**
     * Get the fields displayed by the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function fields(Request $request)
    {
        return [
            ID::make(__('ID'), 'id')->sortable(),
            BelongsTo::make('Page')->nullable(),
            BelongsTo::make('Content Page')->nullable(),
            BelongsTo::make('Homepage')->nullable(),
            new Panel('Open Graph', $this->ogFields()),
            new Panel('Twitter', $this->twitterFields()),
        ];
    }
        
    protected function ogFields() {
        return [
            Text::make('Title', 'og_title')->rules('required', 'max:60'),
            Image::make(__('Image'), 'og_image')
                ->hideFromIndex()
                ->disk('s3')
                ->creationRules('required', 'mimes:jpg,png,gif')  
                ->updateRules('nullable', 'mimes:jpg,png,gif'),     
            Select::make('Type', 'og_type')->options([
                'article' => 'Article',
                'website' => 'Website'
            ])
            ->displayUsingLabels()
            ->rules('required', 'max:20'),
            Textarea::make('Description', 'og_description')->rules('required', 'max:1000'),
        ];
    }

    protected function twitterFields() {
        return [
            Select::make('Card', 'twitter_card')->options([
                'summary' => 'Summary',
                'summary_large_image' => 'Summary Large Image',
                'app' => 'App',
                'player' => 'Player'
            ])
            ->displayUsingLabels()
            ->rules('required', 'max:30'),
            Text::make('Site', 'twitter_site')->rules('required', 'max:50'),
            Text::make('Creator', 'twitter_creator')->rules('required', 'max:50'),
            Text::make('Title', 'twitter_title')->rules('required', 'max:70'),
            Textarea::make('Description', 'twitter_description')->rules('required', 'max:1000'),
            Image::make(__('Image'), 'twitter_image')
                ->hideFromIndex()
                ->disk('s3')
                ->creationRules('required', 'mimes:jpg,png,gif')  
                ->updateRules('nullable', 'mimes:jpg,png,gif'),
            Text::make('Image Alt', 'twitter_image_alt')->rules('required', 'max:1000'),
        ];
    }

    /**
     * Get the cards available for the request.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function cards(Request $request)
    {
        return [];
    }

    /**
     * Get the filters available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function filters(Request $request)
    {
        return [];
    }

    /**
     * Get the lenses available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function lenses(Request $request)
    {
        return [];
    }

    /**
     * Get the actions available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function actions(Request $request)
    {
        return [];
    }
}
