<?php

namespace App\Nova;

use Illuminate\Http\Request;
use Laravel\Nova\Fields\ID;
use Laravel\Nova\Fields\BelongsTo;
use Laravel\Nova\Fields\Text;
use Laravel\Nova\Fields\Textarea;
use Laravel\Nova\Fields\Select;
use Laravel\Nova\Fields\Image;
use Laravel\Nova\Http\Requests\NovaRequest;

use OptimistDigital\NovaSortable\Traits\HasSortableRows;

use App\Nova\Filters\PageFilter;

class Sponsor extends Resource
{
    use HasSortableRows;
    
    /**
     * The number of resources to show per page via relationships.
     *
     * @var int
     */
    public static $perPageViaRelationship = 50;

    /**
     * The model the resource corresponds to.
     *
     * @var string
     */
    public static $model = \App\Models\Sponsor::class;

    /**
     * The group in which this resource belongs to.
     */
    public static $group = 'Event Content';

    /**
     * The single value that should be used to represent the resource when being displayed.
     *
     * @var string
     */
    public static $title = 'id';

    /**
     * The columns that should be searched.
     *
     * @var array
     */
    public static $search = [
        'id', 'name', 'url'
    ];

    /**
     * Get the fields displayed by the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function fields(Request $request)
    {
        return [
            ID::make(__('ID'), 'id')->sortable(),
            BelongsTo::make('Page'),
            Text::make(__('Name'), 'name')
                ->rules('required', 'max:100'),
            Textarea::make(__('Bio'), 'bio')
                ->rules('required'),
            Text::make(__('Relationship'), 'relationship')
                ->hideFromIndex()
                ->rules('required', 'max:100'),
            Text::make(__('URL'), 'url')
                ->rules('required', 'url', 'max:200'),    
            Select::make(__('Status'), 'status')
                ->options([
                    0 => 'Inactive', 
                    1 => 'Active'
                ])
                ->displayUsingLabels()
                ->rules('required'),
            Image::make(__('Filename'), 'filename')
                ->disk('s3')
                ->nullable()
                ->rules('nullable', 'mimes:jpg,png,gif,svg')          
        ];
    }

    /**
     * Get the cards available for the request.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function cards(Request $request)
    {
        return [];
    }

    /**
     * Get the filters available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function filters(Request $request)
    {
        return [
            new PageFilter
        ];
    }

    /**
     * Get the lenses available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function lenses(Request $request)
    {
        return [];
    }

    /**
     * Get the actions available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function actions(Request $request)
    {
        return [];
    }
}
