<?php

namespace App\Nova;

use Illuminate\Http\Request;
use Laravel\Nova\Fields\ID;
use Laravel\Nova\Fields\Text;
use Laravel\Nova\Fields\Textarea;
use Laravel\Nova\Fields\Markdown;
use Laravel\Nova\Fields\BelongsTo;
use Laravel\Nova\Fields\Select;

use Laravel\Nova\Http\Requests\NovaRequest;

use App\Nova\Filters\PageFilter;

class Travel extends Resource
{
    /**
     * The model the resource corresponds to.
     *
     * @var string
     */
    public static $model = \App\Models\Travel::class;

    /**
     * The group in which this resource belongs to.
     */
    public static $group = 'Event Content';

    /**
     * The single value that should be used to represent the resource when being displayed.
     *
     * @var string
     */
    public static $title = 'name';

    /**
     * The columns that should be searched.
     *
     * @var array
     */
    public static $search = [
        'id','name', 'description'
    ];

    /**
     * Get the fields displayed by the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function fields(Request $request)
    {
        return [
            ID::make(__('ID'), 'id')->sortable(),
            BelongsTo::make('Page'),
            Text::make(__('Name'), 'name')->rules('required', 'max:100'),
            Markdown::make(__('Description'), 'description')->rules('required'),
            Text::make(__('Website'), 'website')->rules('nullable', 'url', 'max:200'),  
            Select::make(__('SVG Icon'), 'icon')
                ->options([
                    'airplane' => 'Airplane',
                    'bus' => 'Bus',
                    'car' => 'Car',
                    'train' => 'Train',
                    'taxi' => 'Taxi',
                    'bicycle' => 'Bicycle',
                ])
                ->rules('required'),        
            Select::make(__('Status'), 'status')
                ->options([
                    0 => 'Inactive', 
                    1 => 'Active'
                ])
                ->displayUsingLabels()
                ->rules('required')                 

        ];
    }

    /**
     * Get the cards available for the request.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function cards(Request $request)
    {
        return [];
    }

    /**
     * Get the filters available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function filters(Request $request)
    {
        return [
            new PageFilter
        ];
    }

    /**
     * Get the lenses available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function lenses(Request $request)
    {
        return [];
    }

    /**
     * Get the actions available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function actions(Request $request)
    {
        return [];
    }
}
