<?php

namespace App\Observers;

use App\Models\Registration;
use App\Models\User;
use App\Actions\Fortify\CreateNewUser;
use App\Mail\SendPortalRegistrationEmail;

use Illuminate\Support\Str;
use Illuminate\Support\Facades\Mail;

class RegistrationObserver
{
    /**
     * Handle the Registration "updated" event.
     *
     * @param  \App\Models\Registration  $registration
     * @return void
     */
    public function updated(Registration $registration)
    {
        if ($registration->portal && ($registration->status === 1 || $registration->status === 2)) {

            foreach($registration->attendees()->get() as $attendee) {
                $user = User::where('email', $attendee->email)->first();

                if (!$user) {
                    $password = Str::random(12);

                    $user = (new CreateNewUser)->create([
                        'forename' => $attendee->forename,
                        'surname' => $attendee->surname,
                        'email' => $registration->email,
                        'password' => $password,
                        'password_confirmation' => $password,
                        'portal' => $registration->portal,
                    ]);

                    if ($user) {
                        Mail::to($attendee->email)
                            ->send(new SendPortalRegistrationEmail($registration, $user, $password));
                    }
                }
            }
        }
    }
}
