<?php

namespace App\View\Components\Portal\Lists;

use Illuminate\View\Component;

use App\Models\Registration;
use App\Models\Attendee;
use App\Models\Page;

class ListAttendees extends Component
{
    public $page;
    public $attendees;

    /**
     * Create a new component instance.
     *
     * @return void
     */
    public function __construct(Page $page)
    {
        $this->page = $page;
        if (request()->has('query')) {
            $value = request()->query('query');
            $this->attendees = Attendee::join('users', 'attendees.email', '=', 'users.email')
                ->whereIn('attendees.registration_id',
                    Registration::where('page_id', $page->id)->pluck('id')->toArray()
                )
                ->where('users.portal', 1)
                ->where(function($query) use ($value) {
                    $query
                        ->orWhere('attendees.forename', 'like', '%' . $value . '%')
                        ->orWhere('attendees.surname', 'like', '%' . $value . '%');
                })
                ->orderBy('users.portal', 'DESC')
                ->simplePaginate(24);
        } else {
            $this->attendees = Attendee::join('users', 'attendees.email', '=', 'users.email')
                ->whereIn('attendees.registration_id',
                    Registration::where('page_id', $page->id)
                    ->pluck('id')
                    ->toArray()
                )
                ->orderBy('users.portal', 'DESC')
                ->simplePaginate(24);

        }
    }

    /**
     * Get the view / contents that represent the component.
     *
     * @return \Illuminate\Contracts\View\View|\Closure|string
     */
    public function render()
    {
        return view('components.portal.lists.list-attendees');
    }
}
