@push('header')
    <link rel="stylesheet" href="https://unpkg.com/leaflet@1.7.1/dist/leaflet.css"/>
@endpush
@push('footer')
    <script src="https://unpkg.com/leaflet@1.7.1/dist/leaflet.js"></script>
    @if ($page->longitude && $page->latitude)
        <script>
            var map = L.map('map').setView([{{$page->longitude}}, {{$page->latitude}}], 13);
            map.scrollWheelZoom.disable();
            var marker = new L.Marker([{{$page->longitude}}, {{$page->latitude}}]);
            marker.addTo(map);
            L.tileLayer('https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png', { subdomains: ['a', 'b', 'c'] }).addTo(map)
        </script>
    @endif
@endpush

<x-layout.portal>
    <x-slot name="title">Event Portal</x-slot>
    <x-slot name="description">Event Portal Social Network</x-slot>
    @php
        $subheading = $page->name . ' Venue';
    @endphp
    <x-portal.parts.part-header heading="Event Portal" :subheading="$subheading" :page="$page"/>
    <livewire:portal.menus.menu-main :page="$page" selected="venue"/>
    <div class="container lg:max-w-screen-lg mx-auto">  
        <div class="p-4 lg:p-0">  
            <!--TOP ADVERT-->
            <livewire:portal.ads.advert zone="5b4ce154-02e3-4847-901c-6aa4e18152e7"/>
            <h2 class="text-2xl lg:text-3xl font-altgothic uppercase mb-4">Venue & Travel</h2>
            <div class="grid grid-cols-12 gap-4">
                <livewire:portal.sidebars.sidebar-container :page="$page"/>
                <div class="col-span-12 lg:col-span-9">
                    <div class="bg-white shadow p-4">
                        <div class="full-content">
                            {!! Str::markdown($page->venue) !!}
                        </div>
                        @if ($page->longitude && $page->latitude)
                            <div id="map" class="w-full h-96 mt-4"></div>
                        @endif        
                        @if ($page->travel)
                            <h2 class="text-xl font-serif mb-4 mt-4">Travel</h2>
                            <div class="full-content">
                                {!! Str::markdown($page->travel) !!}
                            </div>
                        @endif                    
                    </div>
                </div>
            </div>
        </div>
    </div>
    <livewire:portal.dialogs.dialog-user :page="$page"/>
</x-layout.portal>