<?php

use Illuminate\Support\Facades\Route;

// Assets
use App\Http\Controllers\Assets\AssetDownloadController;
use App\Http\Controllers\Assets\AssetFileDownloadController;
use App\Http\Controllers\Assets\AssetImageController;

// Checkouts
use App\Http\Controllers\Page\PageCheckoutController;
use App\Http\Controllers\Page\PageCheckoutPaymentController;
use App\Http\Controllers\Page\PageCheckoutSkipController;
use App\Http\Controllers\Page\PageCheckoutCompleteController;
use App\Http\Controllers\Page\PageCheckoutPaymentIntentController;

// Stripe
use App\Http\Controllers\Stripe\StripeWebhookController;

// Site Content
use App\Http\Controllers\Page\PageController;
use App\Http\Controllers\Page\PageErrorController;
use App\Http\Controllers\Page\PageContentController;

// Homepage
use App\Http\Controllers\Home\HomeController;

// Portal
use App\Http\Controllers\Portal\PortalController;
use App\Http\Controllers\Portal\PortalPageController;
use App\Http\Controllers\Portal\PortalAttendeesController;
use App\Http\Controllers\Portal\PortalSpeakersController;
use App\Http\Controllers\Portal\PortalPartnersController;
use App\Http\Controllers\Portal\PortalAgendaController;
use App\Http\Controllers\Portal\PortalMyEventController;
use App\Http\Controllers\Portal\PortalProfileController;
use App\Http\Controllers\Portal\PortalFloorplanController;
use App\Http\Controllers\Portal\PortalVenueController;
use App\Http\Controllers\Portal\PortalNotificationsController;
use App\Http\Controllers\Portal\PortalConnectionsController;
use App\Http\Controllers\Portal\PortalChatController;
use App\Http\Controllers\Portal\PortalCalendarDownloadController;
use App\Http\Controllers\Assets\AssetPortalAvatarController;

Route::get('/', HomeController::class)->name('home');

Route::get('/page/{page}/checkout', [PageCheckoutController::class, 'show'])->name('page.checkout');
Route::get('/page/{page}/checkout/payment', [PageCheckoutPaymentController::class, 'show'])->name('page.checkout.payment');
Route::post('/page/{page}/checkout/payment/intent', [PageCheckoutPaymentIntentController::class, 'show'])->name('page.checkout.payment.intent');
Route::get('/page/{page}/checkout/skip', PageCheckoutSkipController::class)->name('page.checkout.skip');
Route::get('/page/{page}/checkout/complete', PageCheckoutCompleteController::class)->name('page.checkout.complete');
Route::get('/page/{page}', PageController::class)->name('page');
Route::get('/page/{page}/error', PageErrorController::class)->name('page.error');

Route::get('/content/{page}', PageContentController::class)->name('content.page');

Route::post('/stripe/webhook', StripeWebhookController::class)->name('stripe.webhook');

Route::get('/image/{filename}/{width}/{height}', AssetImageController::class)->name('image');

Route::get('/downloads/files/{identifier}', [AssetFileDownloadController::class, 'show'])->name('download.file.show');
Route::get('/downloads/files/{identifier}/download', [AssetFileDownloadController::class, 'download'])->name('download.file.download');
Route::get('/downloads/{identifier}', AssetDownloadController::class)->middleware('nova')->name('download.data');

Route::prefix('portal')->middleware('auth')->group(function() {
    Route::get('/', PortalController::class)->name('portal.home');
    Route::get('/{page}', PortalPageController::class)->name('portal.page');
    Route::get('/{page}/attendees', PortalAttendeesController::class)->name('portal.attendees');
    Route::get('/{page}/speakers', PortalSpeakersController::class)->name('portal.speakers');
    Route::get('/{page}/partners', PortalPartnersController::class)->name('portal.partners');
    Route::get('/{page}/agenda', PortalAgendaController::class)->name('portal.agenda');
    Route::get('/{page}/my-event', PortalMyEventController::class)->name('portal.my-event');
    Route::get('/{page}/profile', [PortalProfileController::class, 'show'])->name('portal.profile');
    Route::post('/{page}/profile', [PortalProfileController::class, 'update'])->name('portal.profile.update');
    Route::get('/{page}/venue', PortalVenueController::class)->name('portal.venue');
    Route::get('/{page}/floorplan', PortalFloorplanController::class)->name('portal.floorplan');
    Route::get('/{page}/notifications', PortalNotificationsController::class)->name('portal.notifications');
    Route::get('/{page}/connections', PortalConnectionsController::class)->name('portal.connections');
    Route::get('/{page}/chats', PortalChatController::class)->name('portal.chats');
    Route::get('/{page}/calendar/download', PortalCalendarDownloadController::class)->name('portal.calendar.download');
    Route::get('/image/{filename}/{width}/{height}', AssetPortalAvatarController::class)->name('portal.avatar.image');
});

Route::post('/timezone', function(Request $request) {
    if (request()->has('timezone') && !session()->has('timezone')) {
        session()->put('timezone', request()->input('timezone'));
    } 
    return response()->json([
        'timezone' => request()->session()->get('timezone')
    ], 200);
});