<?php

namespace Tests\Browser;

use Illuminate\Foundation\Testing\DatabaseMigrations;
use Illuminate\Foundation\Testing\DatabaseTruncation;

use Laravel\Dusk\Browser;
use Tests\DuskTestCase;

use App\Models\Page;
use App\Models\Form;
use App\Models\PricingGroup;
use App\Models\PricingGroupPrice;

class CheckoutProcessPortalDataTest extends DuskTestCase
{
    use DatabaseTruncation;

    public function test_checkout_sets_portal()
    {
        $page = Page::factory()->state([
            'portal' => 1,
            'layout' => json_encode([
                [
                    "id" => "form1",
                    "form" => 1,
                    "name" => "Registration",
                    "type" => "blocks.form-block",
                    "blocks" => "page"
                ],                
            ])
        ])->create();

        $form = Form::factory()->state([
            'id' => 1,
            'url' => '/page/'. $page->slug .'/checkout',
            'fields' => json_encode([
                [
                    "id" => "14211f6f347",
                    "name" => "Pricing Block",
                    "type" => "blocks.pricing-block",
                    "group" => 1
                ],                  
                [
                    "id" => "title",
                    "name" => "Title",
                    "slug" => "title",
                    "type" => "inputs.text-input",
                    "label" => "Title",   
                    "validation" => [
                        "required" => true
                    ]                 
                ],                
                [
                    "id" => "forename",
                    "name" => "Forename",
                    "slug" => "forename",
                    "type" => "inputs.text-input",
                    "label" => "Forename",                    
                    "validation" => [
                        "required" => true
                    ]                 
                ],                
                [
                    "id" => "surname",
                    "name" => "Surname",
                    "slug" => "surname",
                    "type" => "inputs.text-input",
                    "label" => "Surname",
                    "validation" => [
                        "required" => true
                    ]                 
                                        
                ],                
                [
                    "id" => "email",
                    "name" => "Email",
                    "slug" => "email",
                    "type" => "inputs.text-input",
                    "label" => "Email",
                    "validation" => [
                        "required" => true
                    ]                                    
                ],
                [
                    "id" => "promo",
                    "name" => "Promo",
                    "slug" => "promo",
                    "type" => "inputs.text-input",
                    "label" => "Promo",
                ],
                [
                    "id" => "portal",
                    "name" => "portal",
                    "slug" => "portal",
                    "type" => "inputs.portal-check-box-input",
                    "label" => "Portal?",
                ]
                
            ])
        ])->create();

        $group = PricingGroup::factory()->state([
            'page_id' => $page->id  
        ])->create();

        $price = PricingGroupPrice::factory()->create([
            'pricing_group_id' => $group->id
        ]);

        $this->browse(function (Browser $browser) use ($page, $price) {
            $browser->visit('/page/' . $page->slug)
                ->pause(500)
                ->type('@title', 'Mr')
                ->pause(500)
                ->type('@forename', 'Test')
                ->pause(500)
                ->type('@surname', 'Mann')
                ->pause(500)
                ->type('@email', 'test@example.com')
                ->pause(500)
                ->check('@portal')
                ->pause(500)
                ->press('@submit')
                ->pause(500)
                ->assertPathIs('/page/'. $page->slug .'/checkout');
        });

        $this->assertDatabaseHas('registrations', [
            'title' => 'Mr',
            'forename' => 'Test',
            'surname' => 'Mann',
            'email' => 'test@example.com',
            'portal' => 1
        ]);

    }

    public function test_checkout_does_not_set_portal()
    {
        $page = Page::factory()->state([
            'portal' => 1,
            'layout' => json_encode([
                [
                    "id" => "form1",
                    "form" => 1,
                    "name" => "Registration",
                    "type" => "blocks.form-block",
                    "blocks" => "page"
                ],                
            ])
        ])->create();

        $form = Form::factory()->state([
            'id' => 1,
            'url' => '/page/'. $page->slug .'/checkout',
            'fields' => json_encode([
                [
                    "id" => "14211f6f347",
                    "name" => "Pricing Block",
                    "type" => "blocks.pricing-block",
                    "group" => 1
                ],                
                [
                    "id" => "title",
                    "name" => "Title",
                    "slug" => "title",
                    "type" => "inputs.text-input",
                    "label" => "Title",   
                    "validation" => [
                        "required" => true
                    ]                 
                ],                
                [
                    "id" => "forename",
                    "name" => "Forename",
                    "slug" => "forename",
                    "type" => "inputs.text-input",
                    "label" => "Forename",                    
                    "validation" => [
                        "required" => true
                    ]                 
                ],                
                [
                    "id" => "surname",
                    "name" => "Surname",
                    "slug" => "surname",
                    "type" => "inputs.text-input",
                    "label" => "Surname",
                    "validation" => [
                        "required" => true
                    ]                 
                                        
                ],                
                [
                    "id" => "email",
                    "name" => "Email",
                    "slug" => "email",
                    "type" => "inputs.text-input",
                    "label" => "Email",
                    "validation" => [
                        "required" => true
                    ]                                    
                ],
                [
                    "id" => "promo",
                    "name" => "Promo",
                    "slug" => "promo",
                    "type" => "inputs.text-input",
                    "label" => "Promo",
                ],
                [
                    "id" => "portal",
                    "name" => "portal",
                    "slug" => "portal",
                    "type" => "inputs.portal-check-box-input",
                    "label" => "Portal?",
                ]
                
            ])
        ])->create();

        $group = PricingGroup::factory()->state([
            'page_id' => $page->id  
        ])->create();

        $price = PricingGroupPrice::factory()->create([
            'pricing_group_id' => $group->id
        ]);

        $this->browse(function (Browser $browser) use ($page, $price) {
            $browser->visit('/page/' . $page->slug)
                ->pause(500)
                ->type('@title', 'Mr')
                ->pause(500)
                ->type('@forename', 'Test')
                ->pause(500)
                ->type('@surname', 'Mann')
                ->pause(500)
                ->type('@email', 'test@example.com')
                ->pause(500)
                ->press('@submit')
                ->pause(500)
                ->assertPathIs('/page/'. $page->slug .'/checkout');
        });

        $this->assertDatabaseHas('registrations', [
            'title' => 'Mr',
            'forename' => 'Test',
            'surname' => 'Mann',
            'email' => 'test@example.com',
            'portal' => 0
        ]);

    }


}
