<?php

namespace Tests\Feature\Portal\Livewire;

use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Foundation\Testing\WithFaker;
use Tests\TestCase;
use Livewire\Livewire;

use App\Http\Livewire\Portal\Dialogs\DialogSpeaker;

use App\Models\Speaker;
use App\Models\Page;

class DialogSpeakerTest extends TestCase
{
    use RefreshDatabase;

    public function test_dialog_speaker_renders()
    {
        $page = Page::factory()->create();

        $speaker = Speaker::factory()->state(['page_id' => $page->id])->create();

        Livewire::test(DialogSpeaker::class, ['page' => $page])
            ->assertViewIs('livewire.portal.dialogs.dialog-speaker');
    }

    public function test_dialog_speaker_opens()
    {
        $page = Page::factory()->create();

        $speaker = Speaker::factory()->state(['page_id' => $page->id])->create();

        Livewire::test(DialogSpeaker::class, ['page' => $page])
            ->call('openSpeakerDialog', $speaker->id)
            ->assertSet('open', true)
            ->assertSet('selected', $speaker->id)
            ->assertSee($speaker->name);   
    }

    public function test_dialog_speaker_closes()
    {
        $page = Page::factory()->create();

        $speaker = Speaker::factory()->state(['page_id' => $page->id])->create();

        Livewire::test(DialogSpeaker::class, ['page' => $page])
            ->call('openSpeakerDialog', $speaker->id)
            ->assertSet('open', true)
            ->assertSee($speaker->name)
            ->call('closeSpeakerDialog')
            ->assertSet('open', false);
    }    

}

