<?php

namespace Tests\Feature\Portal\Livewire;

use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Foundation\Testing\WithFaker;
use Tests\TestCase;
use Livewire\Livewire;

use App\Http\Livewire\Portal\Dialogs\DialogSponsor;

use App\Models\Sponsor;
use App\Models\Page;

class DialogSponsorTest extends TestCase
{
    use RefreshDatabase;

    public function test_dialog_sponsor_renders()
    {
        $page = Page::factory()->create();

        $sponsor = Sponsor::factory()->state(['page_id' => $page->id])->create();

        Livewire::test(DialogSponsor::class, ['page' => $page])
            ->assertViewIs('livewire.portal.dialogs.dialog-sponsor');
    }

    public function test_dialog_sponsor_opens()
    {
        $page = Page::factory()->create();

        $sponsor = Sponsor::factory()->state(['page_id' => $page->id])->create();

        Livewire::test(DialogSponsor::class, ['page' => $page])
            ->call('openSponsorDialog', $sponsor->id)
            ->assertSet('open', true)
            ->assertSet('selected', $sponsor->id)
            ->assertSee($sponsor->name);   
    }

    public function test_dialog_sponsor_closes()
    {
        $page = Page::factory()->create();

        $sponsor = Sponsor::factory()->state(['page_id' => $page->id])->create();

        Livewire::test(DialogSponsor::class, ['page' => $page])
            ->call('openSponsorDialog', $sponsor->id)
            ->assertSet('open', true)
            ->assertSee($sponsor->name)
            ->call('closeSponsorDialog')
            ->assertSet('open', false);
    }    

}

