<?php

namespace Tests\Feature\Portal\Livewire;

use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Foundation\Testing\WithFaker;
use Tests\TestCase;
use Livewire\Livewire;

use App\Http\Livewire\Portal\Dialogs\DialogUser;

use App\Models\User;
use App\Models\Attendee;
use App\Models\Registration;
use App\Models\Portal\Profile;
use App\Models\Page;

class DialogUserTest extends TestCase
{
    use RefreshDatabase;

    public function test_dialog_user_renders()
    {
        $page = Page::factory()->create();

        $user = User::factory()->create();

        $registration = Registration::factory()->create(['page_id' => $page->id, 'email' => $user->email]);

        $attendee = Attendee::factory()->create(['email' => $user->email]);

        Livewire::test(DialogUser::class, ['page' => $page])
            ->assertViewIs('livewire.portal.dialogs.dialog-user');
    }

    public function test_dialog_sponsor_opens()
    {
        $page = Page::factory()->create();

        $user = User::factory()->create();

        $this->actingAs($user);

        $registration = Registration::factory()->create(['page_id' => $page->id, 'email' => $user->email]);

        $attendee = Attendee::factory()->create(['email' => $user->email]);

        $profile = Profile::factory()->create(['user_id' => $user->id]);

        Livewire::test(DialogUser::class, ['page' => $page])
            ->call('openUserDialog', $user->id)
            ->assertSet('open', true);
    }

    public function test_dialog_user_closes()
    {
        $page = Page::factory()->create();

        $user = User::factory()->create();

        $this->actingAs($user);

        $registration = Registration::factory()->create(['page_id' => $page->id, 'email' => $user->email]);

        $attendee = Attendee::factory()->create(['email' => $user->email]);

        $profile = Profile::factory()->create(['user_id' => $user->id]);

        Livewire::test(DialogUser::class, ['page' => $page])
            ->call('openUserDialog', $user->id)
            ->assertSet('open', true)
            ->call('closeUserDialog')
            ->assertSet('open', false);

    }    

}

