<?php

namespace Tests\Feature\Portal\Livewire;

use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Foundation\Testing\WithFaker;
use Tests\TestCase;
use Livewire\Livewire;

use App\Models\Page;

use App\Http\Livewire\Portal\Filters\FilterAttendees;

class FilterAttendeesTest extends TestCase
{
    use RefreshDatabase;

    public function test_filter_attendees_renders()
    {
        $page = Page::factory()->create();

        Livewire::test(FilterAttendees::class, ['page' => $page])
            ->assertSet('page', $page)
            ->assertViewIs('livewire.portal.filters.filter-attendees');

    }

    public function test_filter_sets_query_from_request()
    {
        $page = Page::factory()->create();

        Livewire::withQueryParams(['query' => 'test'])
            ->test(FilterAttendees::class, ['page' => $page])
            ->assertSet('query', 'test')
            ->assertSet('page', $page);
    }

    public function test_filter_attendees_query_missing()
    {
        $page = Page::factory()->create();

        Livewire::test(FilterAttendees::class, ['page' => $page])
            ->set('query', '')
            ->call('filter')
            ->assertHasErrors(['query' => 'required']);
    }

    public function test_filter_attendees_query_too_short()
    {
        $page = Page::factory()->create();

        Livewire::test(FilterAttendees::class, ['page' => $page])
            ->set('query', 'a')
            ->call('filter')
            ->assertHasErrors(['query' => 'min']);
    }


    public function test_filter_attendees_redirects_to_query()
    {
        $page = Page::factory()->create();

        Livewire::test(FilterAttendees::class, ['page' => $page])
            ->set('query', 'test')
            ->call('filter')
            ->assertRedirect(route('portal.attendees', ['page' => $page->slug, 'query' => 'test']));
    }


    public function test_filter_attendees_redirects_to_clear()
    {
        $page = Page::factory()->create();

        Livewire::test(FilterAttendees::class, ['page' => $page])
            ->call('clear')
            ->assertRedirect(route('portal.attendees', ['page' => $page->slug]));
    }    
}