<?php

namespace Tests\Feature\Portal\Livewire;

use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Foundation\Testing\WithFaker;
use Tests\TestCase;
use Livewire\Livewire;

use App\Models\Page;
use App\Models\User;

use App\Http\Livewire\Portal\Sidebars\SidebarContainer;

class SidebarContainerTest extends TestCase
{
    use RefreshDatabase;

    public function test_sidebar_container_renders()
    {
        $auth = User::factory()->create();
        $page = Page::factory()->create();

        $this->actingAs($auth);

        Livewire::test(SidebarContainer::class, ['page' => $page])
            ->assertViewIs('livewire.portal.sidebars.sidebar-container');
    }

    public function test_sidebar_container_open()
    {
        $auth = User::factory()->create();
        $page = Page::factory()->create();

        $this->actingAs($auth);

        Livewire::test(SidebarContainer::class, ['page' => $page])
            ->call('toggleOpen')
            ->assertSet('open', true);
    }

    public function test_sidebar_container_closed()
    {
        $auth = User::factory()->create();
        $page = Page::factory()->create();

        $this->actingAs($auth);

        Livewire::test(SidebarContainer::class, ['page' => $page])
            ->call('toggleOpen')
            ->assertSet('open', true)
            ->call('toggleOpen')
            ->assertSet('open', false);
    }    


}