<?php

namespace Tests\Feature\Site\Livewire;

use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Foundation\Testing\WithFaker;
use Tests\TestCase;
use Livewire\Livewire;

use App\Models\Page;
use App\Models\PricingGroup;
use App\Models\PricingGroupPrice;
use App\Models\Registration;    

use App\Http\Livewire\Ecommerce\Attendees;

class AttendeesTest extends TestCase
{
    use RefreshDatabase;

    public function test_attendees_single_attendee()
    {
        $page = Page::factory()->create();

        $registration = Registration::factory()->create();

        $group = PricingGroup::factory()->state([
            'page_id' => $page->id  
        ])->create();

        $price = PricingGroupPrice::factory()->create([
            'pricing_group_id' => $group->id
        ]);

        $attendees = [
            [
                'forename' => 'Test',
                'surname' => 'User',
                'email' => 'test@example.com'
            ]
        ];        

        session([
            'registration' => $registration,
            'attendees' => $attendees,
            'price' => $price,
            'extras' => [],
        ]);

        Livewire::test(Attendees::class, ['page' => $page])
            ->assertSet('page', $page)
            ->assertSet('registration', $registration)
            ->assertSet('attendees', $attendees)
            ->assertSee('Ticket Prices')
            ->assertSeeHtml(sprintf('<span class="shrink">&#163;%s Each</span>', number_format($price->price,2)))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Forename: </span>%s', $attendees[0]['forename']))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Surname: </span>%s', $attendees[0]['surname']))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Email: </span>%s', $attendees[0]['email']))
            ->assertSeeHtml('<input id="forename')
            ->assertSeeHtml('<input id="surname')
            ->assertSeeHtml('<input id="email')
            ->assertSee('Remove')
            ->assertSee('Add');

    }

    public function test_attendees_multiple_attendees()
    {
        $page = Page::factory()->create();

        $registration = Registration::factory()->create();

        $group = PricingGroup::factory()->state([
            'page_id' => $page->id  
        ])->create();

        $price = PricingGroupPrice::factory()->create([
            'pricing_group_id' => $group->id
        ]);

        $attendees = [
            [
                'forename' => 'Test1',
                'surname' => 'User1',
                'email' => 'test1@example.com'
            ],
            [
                'forename' => 'Test2',
                'surname' => 'User2',
                'email' => 'test2@example.com'
            ]
        ];        

        session([
            'registration' => $registration,
            'attendees' => $attendees,
            'price' => $price,
            'extras' => []
        ]);

        Livewire::test(Attendees::class, ['page' => $page])
            ->assertSet('page', $page)
            ->assertSet('registration', $registration)
            ->assertSet('attendees', $attendees)
            ->assertSee('Ticket Prices')
            ->assertSeeHtml(sprintf('<span class="shrink">&#163;%s Each</span>', number_format($price->price,2)))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Forename: </span>%s', $attendees[0]['forename']))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Surname: </span>%s', $attendees[0]['surname']))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Email: </span>%s', $attendees[0]['email']))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Forename: </span>%s', $attendees[1]['forename']))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Surname: </span>%s', $attendees[1]['surname']))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Email: </span>%s', $attendees[1]['email']))
            ->assertSeeHtml('<input id="forename')
            ->assertSeeHtml('<input id="surname')
            ->assertSeeHtml('<input id="email')
            ->assertSee('Add');
    }

    public function test_attendees_multiple_attendees_hidden_form()
    {
        $page = Page::factory()->create();

        $registration = Registration::factory()->create();

        $group = PricingGroup::factory()->state([
            'page_id' => $page->id  
        ])->create();

        $price = PricingGroupPrice::factory()->create([
            'pricing_group_id' => $group->id
        ]);

        $attendees = [
            [
                'forename' => 'Test1',
                'surname' => 'User1',
                'email' => 'test1@example.com'
            ],
            [
                'forename' => 'Test2',
                'surname' => 'User2',
                'email' => 'test2@example.com'
            ],
            [
                'forename' => 'Test3',
                'surname' => 'User3',
                'email' => 'test3@example.com'
            ],
            [
                'forename' => 'Test4',
                'surname' => 'User4',
                'email' => 'test4@example.com'
            ]
            
        ];        

        session([
            'registration' => $registration,
            'attendees' => $attendees,
            'price' => $price,
            'extras' => []
        ]);

        Livewire::test(Attendees::class, ['page' => $page])
            ->assertSet('page', $page)
            ->assertSet('registration', $registration)
            ->assertSet('attendees', $attendees)
            ->assertSee('Ticket Prices')
            ->assertSeeHtml(sprintf('<span class="shrink">&#163;%s Each</span>', number_format($price->price,2)))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Forename: </span>%s', $attendees[0]['forename']))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Surname: </span>%s', $attendees[0]['surname']))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Email: </span>%s', $attendees[0]['email']))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Forename: </span>%s', $attendees[1]['forename']))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Surname: </span>%s', $attendees[1]['surname']))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Email: </span>%s', $attendees[1]['email']))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Forename: </span>%s', $attendees[2]['forename']))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Surname: </span>%s', $attendees[2]['surname']))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Email: </span>%s', $attendees[2]['email']))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Forename: </span>%s', $attendees[3]['forename']))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Surname: </span>%s', $attendees[3]['surname']))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Email: </span>%s', $attendees[3]['email']))
            ->assertDontSeeHtml('<input id="forename')
            ->assertDontSeeHtml('<input id="surname')
            ->assertDontSeeHtml('<input id="email')
            ->assertDontSee('Add')
            ->assertSee('To book more than 4 tickets, please contact us');
    }

    public function test_attendees_multiple_attendees_one_free()
    {
        $page = Page::factory()->create();

        $registration = Registration::factory()->create();

        $group = PricingGroup::factory()->state([
            'page_id' => $page->id  
        ])->create();

        $price = PricingGroupPrice::factory()->create([
            'pricing_group_id' => $group->id,
            'offer' => 'buy-two-get-one-free'
        ]);

        $attendees = [
            [
                'forename' => 'Test1',
                'surname' => 'User1',
                'email' => 'test1@example.com'
            ],
            [
                'forename' => 'Test2',
                'surname' => 'User2',
                'email' => 'test2@example.com'
            ],
            [
                'forename' => 'Test3',
                'surname' => 'User3',
                'email' => 'test3@example.com'
            ]
        ];        

        session([
            'registration' => $registration,
            'attendees' => $attendees,
            'price' => $price,
            'extras' => []
        ]);

        Livewire::test(Attendees::class, ['page' => $page])
            ->assertSet('page', $page)
            ->assertSet('registration', $registration)
            ->assertSet('attendees', $attendees)
            ->assertSee('Ticket Prices')
            ->assertSeeHtml(sprintf('<span class="shrink">&#163;%s Each</span>', number_format($price->price,2)))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Forename: </span>%s', $attendees[0]['forename']))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Surname: </span>%s', $attendees[0]['surname']))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Email: </span>%s', $attendees[0]['email']))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Forename: </span>%s', $attendees[1]['forename']))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Surname: </span>%s', $attendees[1]['surname']))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Email: </span>%s', $attendees[1]['email']))
            ->assertSeeHtml('<span class="text-techcapital-red font-bold block">&#163; FREE</span>');
    }

    public function test_attendees_add_attendee_missing_fails_validation()
    {
        $page = Page::factory()->create();

        $registration = Registration::factory()->create();

        $group = PricingGroup::factory()->state([
            'page_id' => $page->id  
        ])->create();

        $price = PricingGroupPrice::factory()->create([
            'pricing_group_id' => $group->id,
        ]);

        $attendees = [
            [
                'forename' => 'Test1',
                'surname' => 'User1',
                'email' => 'test1@example.com'
            ]
        ];

        session([
            'registration' => $registration,
            'attendees' => $attendees,
            'price' => $price,
            'extras' => []
        ]);

        Livewire::test(Attendees::class, ['page' => $page])
            ->assertSet('page', $page)
            ->assertSet('registration', $registration)
            ->assertSet('attendees', $attendees)
            ->call('submit')
            ->assertHasErrors(['attendee.forename', 'attendee.surname', 'attendee.email']);

    }

    public function test_attendees_add_attendee()
    {
        $page = Page::factory()->create();

        $registration = Registration::factory()->create();

        $group = PricingGroup::factory()->state([
            'page_id' => $page->id  
        ])->create();

        $price = PricingGroupPrice::factory()->create([
            'pricing_group_id' => $group->id,
        ]);

        $attendees = [
            [
                'forename' => 'Test1',
                'surname' => 'User1',
                'email' => 'test1@example.com'
            ]
        ];

        session([
            'registration' => $registration,
            'attendees' => $attendees,
            'price' => $price,
            'extras' => []
        ]);

        Livewire::test(Attendees::class, ['page' => $page])
            ->assertSet('page', $page)
            ->assertSet('registration', $registration)
            ->assertSet('attendees', $attendees)
            ->set('attendee.forename', 'Test2')
            ->set('attendee.surname', 'User2')
            ->set('attendee.email', 'test2@example.com')
            ->call('submit')
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Forename: </span>%s', $attendees[0]['forename']))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Surname: </span>%s', $attendees[0]['surname']))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Email: </span>%s', $attendees[0]['email']))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Forename: </span>%s', 'Test2'))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Surname: </span>%s', 'User2'))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Email: </span>%s', 'test2@example.com'))
            ->assertEmitted('recalculate');

        $this->assertCount(2, session('attendees'));
        $this->assertEquals(session('attendees')[0], $attendees[0]);            
        $this->assertEquals(session('attendees')[1], [
            'forename' => 'Test2',
            'surname' => 'User2',
            'email' => 'test2@example.com'
        ]);            

    }    

    public function test_attendees_remove_attendee()
    {
        $page = Page::factory()->create();

        $registration = Registration::factory()->create();

        $group = PricingGroup::factory()->state([
            'page_id' => $page->id  
        ])->create();

        $price = PricingGroupPrice::factory()->create([
            'pricing_group_id' => $group->id,
        ]);

        $attendees = [
            [
                'forename' => 'Test1',
                'surname' => 'User1',
                'email' => 'test1@example.com'
            ],
            [
                'forename' => 'Test2',
                'surname' => 'User2',
                'email' => 'test2@example.com'
            ]            
        ];

        session([
            'registration' => $registration,
            'attendees' => $attendees,
            'price' => $price,
            'extras' => []
        ]);

        Livewire::test(Attendees::class, ['page' => $page])
            ->assertSet('page', $page)
            ->assertSet('registration', $registration)
            ->assertSet('attendees', $attendees)
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Forename: </span>%s', $attendees[0]['forename']))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Surname: </span>%s', $attendees[0]['surname']))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Email: </span>%s', $attendees[0]['email']))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Forename: </span>%s', $attendees[1]['forename']))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Surname: </span>%s', $attendees[1]['surname']))
            ->assertSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Email: </span>%s', $attendees[1]['email']))
            ->call('remove', 1)
            ->assertDontSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Forename: </span>%s', $attendees[1]['forename']))
            ->assertDontSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Surname: </span>%s', $attendees[1]['surname']))
            ->assertDontSeeHtml(sprintf('<span class="inline-block mr-2 lg:hidden font-bold">Email: </span>%s', $attendees[1]['email']))
            ->assertEmitted('recalculate');

        $this->assertCount(1, session('attendees'));
        $this->assertEquals($attendees[0], session('attendees')[0]);
    }    


}