<?php

namespace Tests\Feature\Site\Livewire\Ecommerce;

use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Foundation\Testing\WithFaker;
use Tests\TestCase;
use Livewire\Livewire;

use App\Models\Page;
use App\Models\PricingGroup;
use App\Models\PricingGroupPrice;
use App\Models\Registration;
use App\Models\PricingExtra;
use App\Models\Extra;

use App\Http\Livewire\Ecommerce\Extras;

class ExtrasTest extends TestCase
{
    use RefreshDatabase;
    
    public function test_extras_shows_single_extra()
    {
        $page = Page::factory()->create();

        $group = PricingGroup::factory()->state([
            'page_id' => $page->id  
        ])->create();

        $price = PricingGroupPrice::factory()->create([
            'pricing_group_id' => $group->id
        ]);

        $pricing_extra = PricingExtra::factory()->create([
            'page_id' => $page->id
        ]);

        $attendees = [
            [
                'forename' => 'Test',
                'surname' => 'User',
                'email' => 'test@example.com'
            ]
        ];

        $registration = Registration::factory()->create();

        $extras = [];

        session([
            'registration' => $registration,
            'attendees' => $attendees,
            'extras' => []
        ]);


        Livewire::test(Extras::class, ['page' => $page])
            ->assertSet('page', $page)
            ->assertSet('registration', $registration)
            ->assertSet('attendees', $attendees)
            ->assertSee('Optional Extras')
            ->assertSeeHtml(sprintf('<h2 class="font-bold">%s - &#163; %s Each</h2>', $pricing_extra->name, number_format($pricing_extra->price, 2)))
            ->assertSeeHtml(sprintf('<p>%s</p>', $pricing_extra->description))
            ->assertSeeHtml('<option value="0"  selected >0</option>')
            ->assertSeeHtml('<option value="1" >1</option>')
            ->assertSeeHtml('<option value="2" >2</option>')
            ->assertSeeHtml('<option value="3" >3</option>')
            ->assertSeeHtml('<option value="4" >4</option>');

    }

    public function test_extras_shows_multiple_extras()
    {
        $page = Page::factory()->create();

        $group = PricingGroup::factory()->state([
            'page_id' => $page->id  
        ])->create();

        $price = PricingGroupPrice::factory()->create([
            'pricing_group_id' => $group->id
        ]);

        $pricing_extra1 = PricingExtra::factory()->create([
            'page_id' => $page->id
        ]);

        $pricing_extra2 = PricingExtra::factory()->create([
            'page_id' => $page->id
        ]);        

        $attendees = [
            [
                'forename' => 'Test',
                'surname' => 'User',
                'email' => 'test@example.com'
            ]
        ];

        $registration = Registration::factory()->create();

        $extras = [];

        session([
            'registration' => $registration,
            'attendees' => $attendees,
            'extras' => []
        ]);


        Livewire::test(Extras::class, ['page' => $page])
            ->assertSet('page', $page)
            ->assertSet('registration', $registration)
            ->assertSet('attendees', $attendees)
            ->assertSee('Optional Extras')
            ->assertSeeHtml(sprintf('<h2 class="font-bold">%s - &#163; %s Each</h2>', $pricing_extra1->name, number_format($pricing_extra1->price, 2)))
            ->assertSeeHtml(sprintf('<p>%s</p>', $pricing_extra1->description))
            ->assertSeeHtml('<option value="0"  selected >0</option>')
            ->assertSeeHtml('<option value="1" >1</option>')
            ->assertSeeHtml('<option value="2" >2</option>')
            ->assertSeeHtml('<option value="3" >3</option>')
            ->assertSeeHtml('<option value="4" >4</option>')
            ->assertSeeHtml(sprintf('<h2 class="font-bold">%s - &#163; %s Each</h2>', $pricing_extra2->name, number_format($pricing_extra2->price, 2)))
            ->assertSeeHtml(sprintf('<p>%s</p>', $pricing_extra2->description))
            ->assertSeeHtml('<option value="0"  selected >0</option>')
            ->assertSeeHtml('<option value="1" >1</option>')
            ->assertSeeHtml('<option value="2" >2</option>')
            ->assertSeeHtml('<option value="3" >3</option>')
            ->assertSeeHtml('<option value="4" >4</option>');            
    }    

    public function test_extras_shows_single_extra_selected_quantity()
    {
        $page = Page::factory()->create();

        $registration = Registration::factory()->create();

        $group = PricingGroup::factory()->state([
            'page_id' => $page->id  
        ])->create();

        $price = PricingGroupPrice::factory()->create([
            'pricing_group_id' => $group->id
        ]);

        $pricing_extra = PricingExtra::factory()->create([
            'page_id' => $page->id
        ]);

        $extra = Extra::factory()->state([
            'registration_id' => $registration->id,
            'pricing_extra_id' => $pricing_extra->id,
            'quantity' => 2,
            'price' => $pricing_extra->price
        ])->create();

        $attendees = [
            [
                'forename' => 'Test',
                'surname' => 'User',
                'email' => 'test@example.com'
            ]
        ];

        $extras = [
            $extra->pricing_extra_id => $extra->quantity
        ];

        session([
            'registration' => $registration,
            'attendees' => $attendees,
            'extras' => $extras
        ]);


        Livewire::test(Extras::class, ['page' => $page])
            ->assertSet('page', $page)
            ->assertSet('registration', $registration)
            ->assertSet('attendees', $attendees)
            ->assertSet('extras', $extras)
            ->assertSee('Optional Extras')
            ->assertSeeHtml(sprintf('<h2 class="font-bold">%s - &#163; %s Each</h2>', $pricing_extra->name, number_format($pricing_extra->price, 2)))
            ->assertSeeHtml(sprintf('<p>%s</p>', $pricing_extra->description))
            ->assertSeeHtml('<option value="0" >0</option>')
            ->assertSeeHtml('<option value="1" >1</option>')
            ->assertSeeHtml('<option value="2"  selected >2</option>')
            ->assertSeeHtml('<option value="3" >3</option>')
            ->assertSeeHtml('<option value="4" >4</option>');
    }


    public function test_extras_shows_single_extra_selected_change_quantity()
    {
        $page = Page::factory()->create();

        $registration = Registration::factory()->create();

        $group = PricingGroup::factory()->state([
            'page_id' => $page->id  
        ])->create();

        $price = PricingGroupPrice::factory()->create([
            'pricing_group_id' => $group->id
        ]);

        $pricing_extra = PricingExtra::factory()->create([
            'page_id' => $page->id
        ]);

        $extra = Extra::factory()->state([
            'registration_id' => $registration->id,
            'pricing_extra_id' => $pricing_extra->id,
            'quantity' => 2,
            'price' => $pricing_extra->price
        ])->create();

        $attendees = [
            [
                'forename' => 'Test',
                'surname' => 'User',
                'email' => 'test@example.com'
            ]
        ];

        $extras = [
            $extra->pricing_extra_id => $extra->quantity
        ];

        session([
            'registration' => $registration,
            'attendees' => $attendees,
            'extras' => $extras
        ]);


        Livewire::test(Extras::class, ['page' => $page])
            ->assertSet('page', $page)
            ->assertSet('registration', $registration)
            ->assertSet('attendees', $attendees)
            ->assertSet('extras', $extras)
            ->assertSee('Optional Extras')
            ->assertSeeHtml('<option value="2"  selected >2</option>')
            ->call('extraChanged', $extra->pricing_extra_id, 1)
            ->assertSeeHtml('<option value="1"  selected >1</option>');
    }

    public function test_extras_shows_single_extra_selected_remove_all()
    {
        $page = Page::factory()->create();

        $registration = Registration::factory()->create();

        $group = PricingGroup::factory()->state([
            'page_id' => $page->id  
        ])->create();

        $price = PricingGroupPrice::factory()->create([
            'pricing_group_id' => $group->id
        ]);

        $pricing_extra = PricingExtra::factory()->create([
            'page_id' => $page->id
        ]);

        $extra = Extra::factory()->state([
            'registration_id' => $registration->id,
            'pricing_extra_id' => $pricing_extra->id,
            'quantity' => 1,
            'price' => $pricing_extra->price
        ])->create();

        $attendees = [
            [
                'forename' => 'Test',
                'surname' => 'User',
                'email' => 'test@example.com'
            ]
        ];

        $extras = [
            $extra->pricing_extra_id => $extra->quantity
        ];

        session([
            'registration' => $registration,
            'attendees' => $attendees,
            'extras' => $extras
        ]);


        Livewire::test(Extras::class, ['page' => $page])
            ->assertSet('page', $page)
            ->assertSet('registration', $registration)
            ->assertSet('attendees', $attendees)
            ->assertSet('extras', $extras)
            ->assertSee('Optional Extras')
            ->assertSeeHtml('<option value="1"  selected >1</option>')
            ->call('extraChanged', $extra->pricing_extra_id, 0)
            ->assertSeeHtml('<option value="0"  selected >0</option>')
            ->assertEmitted('recalculate')
            ->assertSet('extras', []);

        $this->assertEmpty(session('extras'));
    }

}