<?php

namespace Tests\Feature\Site\Livewire\Ecommerce;

use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Foundation\Testing\WithFaker;
use Tests\TestCase;
use Livewire\Livewire;

use App\Models\Page;
use App\Models\PricingGroup;
use App\Models\PricingGroupPrice;
use App\Models\Registration;

use App\Http\Livewire\Ecommerce\Payment;

class PaymentTest extends TestCase
{
    use RefreshDatabase;

    public function test_payment_displays_information_cc_form()
    {
        $page = Page::factory()->create();

        $group = PricingGroup::factory()->state([
            'page_id' => $page->id  
        ])->create();

        $price = PricingGroupPrice::factory()->create([
            'pricing_group_id' => $group->id
        ]);

        $attendees = [
            [
                'forename' => 'Test',
                'surname' => 'User',
                'email' => 'test@example.com'
            ]
        ];

        $registration = Registration::factory()->create();

        $total = $price->price * count($attendees);
        $total_plus_vat = $total * 1.2;

        session([
            'registration' => $registration,
            'attendees' => $attendees,
            'price' => $price,
        ]);

        Livewire::test(Payment::class, ['page' => $page])
            ->assertSet('page', $page)
            ->assertSet('registration', $registration)
            ->assertSet('attendees', $attendees)
            ->assertSeeHtml('<span class="inline-block mr-2 lg:hidden font-bold">Forename: </span>' . $attendees[0]['forename'])
            ->assertSeeHtml('<span class="inline-block mr-2 lg:hidden font-bold">Surname: </span>' . $attendees[0]['surname'])
            ->assertSeeHtml('<span class="inline-block mr-2 lg:hidden font-bold">Email: </span>' . $attendees[0]['email'])
            ->assertSee(number_format($total, 2))
            ->assertSee(number_format($total_plus_vat, 2))
            ->assertSee('Pay now')
            ->assertSee('Cancel Registration')
            ->assertSee('Please make a payment using the form below')
            ->assertSee('Your payment will be processed securely with Stripe');
    }

    public function test_payment_cancel_redirects_to_page()
    {
        $page = Page::factory()->create();

        $group = PricingGroup::factory()->state([
            'page_id' => $page->id  
        ])->create();

        $price = PricingGroupPrice::factory()->create([
            'pricing_group_id' => $group->id
        ]);

        $attendees = [
            [
                'forename' => 'Test',
                'surname' => 'User',
                'email' => 'test@example.com'
            ]
        ];

        $registration = Registration::factory()->create();

        session([
            'registration' => $registration,
            'attendees' => $attendees,
            'price' => $price
        ]);

        // Check on clicking cancel, the registration is deleted and the user is redirected to the page
        Livewire::test(Payment::class, ['page' => $page])
            ->assertSet('page', $page)
            ->assertSet('registration', $registration)
            ->assertSet('attendees', $attendees)
            ->call('cancel')
            ->assertRedirect(route('page', ['page' => $page->slug]));

        // Assert Registration deleted
        $this->assertDatabaseMissing('registrations', ['id' => $registration->id]);

        // Assert session data removed
        $this->assertNull(session()->get('registration'));
        $this->assertNull(session()->get('attendees'));
        $this->assertNull(session()->get('extras'));
    }

}