<?php

namespace Tests\Feature\Site\Livewire\Ecommerce;

use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Foundation\Testing\WithFaker;
use Tests\TestCase;
use Livewire\Livewire;

use App\Models\Page;
use App\Models\PricingGroup;
use App\Models\PricingGroupPrice;
use App\Models\Registration;
use App\Models\PricingExtra;
use App\Models\Extra;
use App\Models\PromoCode;

use App\Http\Livewire\Ecommerce\Totalizer;

class TotalizerTest extends TestCase
{
    use RefreshDatabase;

    public function test_totalizer_shows_correct_single_attendee_no_extra_no_discount_amount()
    {
        $page = Page::factory()->create();

        $group = PricingGroup::factory()->state([
            'page_id' => $page->id  
        ])->create();

        $price = PricingGroupPrice::factory()->create([
            'pricing_group_id' => $group->id
        ]);

        $attendees = [
            [
                'forename' => 'Test',
                'surname' => 'User',
                'email' => 'test@example.com'
            ]
        ];

        $registration = Registration::factory()->create();

        $extras = [];

        $total = number_format($price->price * count($attendees), 2);

        $total_plus_vat = number_format($total * 1.2, 2);

        session(['registration' => $registration, 'attendees' => $attendees, 'extras' => $extras, 'price' => $price]);

        Livewire::test(Totalizer::class, ['page' => $page])
            ->assertSet('page', $page)
            ->assertSet('registration', $registration)
            ->assertSet('attendees', $attendees)
            ->assertSet('extras', $extras)
            ->assertSet('price', $price)
            ->assertSee($total)
            ->assertSee($total_plus_vat);

    }

    public function test_totalizer_shows_correct_multiple_attendees_no_extras_no_discount_amount()
    {
        $page = Page::factory()->create();

        $registration = Registration::factory()->state([
            'page_id' => $page->id  
        ])->create();

        $group = PricingGroup::factory()->state([
            'page_id' => $page->id  
        ])->create();

        $price = PricingGroupPrice::factory()->create([
            'pricing_group_id' => $group->id
        ]);

        $attendees = [
            [
                'forename' => 'Test1',
                'surname' => 'User1',
                'email' => 'test1@example.com'
            ],
            [
                'forename' => 'Test2',
                'surname' => 'User2',
                'email' => 'test2@example.com'
            ]
        ];

        $extras = [];

        $total = number_format($price->price * count($attendees), 2);

        $total_plus_vat = number_format($total * 1.2, 2);

        session(['registration' => $registration, 'attendees' => $attendees, 'extras' => $extras, 'price' => $price]);

        Livewire::test(Totalizer::class, ['page' => $page])
            ->assertSet('page', $page)
            ->assertSet('registration', $registration)
            ->assertSet('attendees', $attendees)
            ->assertSet('extras', $extras)
            ->assertSet('price', $price)
            ->assertSee($total)
            ->assertSee($total_plus_vat);
    }    

    public function test_totalizer_shows_correct_single_attendee_extras_no_discount_amount()
    {
        $page = Page::factory()->create();

        $registration = Registration::factory()->state([
            'page_id' => $page->id  
        ])->create();

        $group = PricingGroup::factory()->state([
            'page_id' => $page->id  
        ])->create();

        $price = PricingGroupPrice::factory()->create([
            'pricing_group_id' => $group->id
        ]);

        $pricing_extra = PricingExtra::factory()->state([
            'page_id' => $page->id
        ])->create();

        $extra = Extra::factory()->state([
            'registration_id' => $registration->id,
            'pricing_extra_id' => $pricing_extra->id,
            'quantity' => 1,
            'price' => $pricing_extra->price
        ])->create();
            
        $attendees = [
            [
                'forename' => 'Test',
                'surname' => 'User',
                'email' => 'test@example.com'
            ]
        ];

        $extras = [
            $extra->pricing_extra_id => $extra->quantity
        ];

        $total = number_format(($price->price * count($attendees)) + ($extra->price * $extra->quantity) , 2);

        $total_plus_vat = number_format($total * 1.2, 2);

        session(['registration' => $registration, 'attendees' => $attendees, 'extras' => $extras, 'price' => $price]);

        Livewire::test(Totalizer::class, ['page' => $page])
            ->assertSet('page', $page)
            ->assertSet('registration', $registration)
            ->assertSet('attendees', $attendees)
            ->assertSet('extras', $extras)
            ->assertSet('price', $price)
            ->assertSee($total)
            ->assertSee($total_plus_vat);

    }    

    public function test_totalizer_shows_correct_single_attendee_multiple_extras_no_discount_amount()
    {
        $page = Page::factory()->create();

        $registration = Registration::factory()->state([
            'page_id' => $page->id  
        ])->create();

        $group = PricingGroup::factory()->state([
            'page_id' => $page->id  
        ])->create();

        $price = PricingGroupPrice::factory()->create([
            'pricing_group_id' => $group->id
        ]);

        $pricing_extra = PricingExtra::factory()->state([
            'page_id' => $page->id
        ])->create();

        $extra = Extra::factory()->state([
            'registration_id' => $registration->id,
            'pricing_extra_id' => $pricing_extra->id,
            'quantity' => 2,
            'price' => $pricing_extra->price
        ])->create();
            
        $attendees = [
            [
                'forename' => 'Test',
                'surname' => 'User',
                'email' => 'test@example.com'
            ]
        ];

        $extras = [
            $extra->pricing_extra_id => $extra->quantity
        ];

        $total = number_format(($price->price * count($attendees)) + ($extra->price * $extra->quantity) , 2);

        $total_plus_vat = number_format($total * 1.2, 2);

        session(['registration' => $registration, 'attendees' => $attendees, 'extras' => $extras, 'price' => $price]);

        Livewire::test(Totalizer::class, ['page' => $page])
            ->assertSet('page', $page)
            ->assertSet('registration', $registration)
            ->assertSet('attendees', $attendees)
            ->assertSet('extras', $extras)
            ->assertSet('price', $price)
            ->assertSee($total)
            ->assertSee($total_plus_vat);

    }    

    public function test_totalizer_shows_correct_multiple_attendees_extras_no_discount_amount()
    {
        $page = Page::factory()->create();

        $registration = Registration::factory()->state([
            'page_id' => $page->id  
        ])->create();

        $group = PricingGroup::factory()->state([
            'page_id' => $page->id  
        ])->create();

        $price = PricingGroupPrice::factory()->create([
            'pricing_group_id' => $group->id
        ]);

        $pricing_extra = PricingExtra::factory()->state([
            'page_id' => $page->id
        ])->create();

        $extra = Extra::factory()->state([
            'registration_id' => $registration->id,
            'pricing_extra_id' => $pricing_extra->id,
            'quantity' => 1,
            'price' => $pricing_extra->price
        ])->create();
            
        $attendees = [
            [
                'forename' => 'Test1',
                'surname' => 'User1',
                'email' => 'test1@example.com'
            ],
            [
                'forename' => 'Test2',
                'surname' => 'User2',
                'email' => 'test2@example.com'
            ]
        ];

        $extras = [
            $extra->pricing_extra_id => $extra->quantity
        ];

        $total = number_format(($price->price * count($attendees)) + ($extra->price * $extra->quantity) , 2);

        $total_plus_vat = number_format($total * 1.2, 2);

        session(['registration' => $registration, 'attendees' => $attendees, 'extras' => $extras, 'price' => $price]);

        Livewire::test(Totalizer::class, ['page' => $page])
            ->assertSet('page', $page)
            ->assertSet('registration', $registration)
            ->assertSet('attendees', $attendees)
            ->assertSet('extras', $extras)
            ->assertSet('price', $price)
            ->assertSee($total)
            ->assertSee($total_plus_vat);

    }    

    public function test_totalizer_shows_correct_with_single_attendee_discount_extra_amount()
    {
        $page = Page::factory()->create();

        $promo = PromoCode::factory()->state([
            'page_id' => $page->id,
            'code' => 'Twenty',
            'discount' => 20
        ])->create();

        $registration = Registration::factory()->state([
            'page_id' => $page->id,
            'promo' => 'Twenty',
        ])->create();

        $group = PricingGroup::factory()->state([
            'page_id' => $page->id  
        ])->create();

        $price = PricingGroupPrice::factory()->create([
            'pricing_group_id' => $group->id
        ]);

        $pricing_extra = PricingExtra::factory()->state([
            'page_id' => $page->id
        ])->create();

        $extra = Extra::factory()->state([
            'registration_id' => $registration->id,
            'pricing_extra_id' => $pricing_extra->id,
            'quantity' => 1,
            'price' => $pricing_extra->price
        ])->create();
            
        $attendees = [
            [
                'forename' => 'Test1',
                'surname' => 'User1',
                'email' => 'test1@example.com'
            ]
        ];

        $extras = [
            $extra->pricing_extra_id => $extra->quantity
        ];

        $attendees_total = $price->price * count($attendees);

        $extras_total = $extra->price * $extra->quantity;

        $discount_total = ($attendees_total + $extras_total) * ($promo->discount / 100);

        $total = ($attendees_total + $extras_total) - $discount_total;

        $total_plus_vat = $total * 1.2;

        session(['registration' => $registration, 'attendees' => $attendees, 'extras' => $extras, 'price' => $price]);

        Livewire::test(Totalizer::class, ['page' => $page])
            ->assertSet('page', $page)
            ->assertSet('registration', $registration)
            ->assertSet('attendees', $attendees)
            ->assertSet('extras', $extras)
            ->assertSet('price', $price)            
            ->assertSee(number_format($total, 2))
            ->assertSee(number_format($total_plus_vat, 2));

    } 

    public function test_totalizer_shows_correct_multiple_attendees_with_discount_extra_amount()
    {
        $page = Page::factory()->create();

        $promo = PromoCode::factory()->state([
            'page_id' => $page->id,
            'code' => 'Twenty',
            'discount' => 20
        ])->create();

        $registration = Registration::factory()->state([
            'page_id' => $page->id,
            'promo' => 'Twenty',
        ])->create();

        $group = PricingGroup::factory()->state([
            'page_id' => $page->id  
        ])->create();

        $price = PricingGroupPrice::factory()->create([
            'pricing_group_id' => $group->id
        ]);

        $pricing_extra = PricingExtra::factory()->state([
            'page_id' => $page->id
        ])->create();

        $extra = Extra::factory()->state([
            'registration_id' => $registration->id,
            'pricing_extra_id' => $pricing_extra->id,
            'quantity' => 1,
            'price' => $pricing_extra->price
        ])->create();
            
        $attendees = [
            [
                'forename' => 'Test1',
                'surname' => 'User1',
                'email' => 'test1@example.com'
            ],
            [
                'forename' => 'Test2',
                'surname' => 'User2',
                'email' => 'test2@example.com'
            ]            
        ];

        $extras = [
            $extra->pricing_extra_id => $extra->quantity
        ];

        $attendees_total = $price->price * count($attendees);

        $extras_total = $extra->price * $extra->quantity;

        $discount_total = ($attendees_total + $extras_total) * ($promo->discount / 100);

        $total = ($attendees_total + $extras_total) - $discount_total;

        $total_plus_vat = $total * 1.2;

        session(['registration' => $registration, 'attendees' => $attendees, 'extras' => $extras, 'price' => $price]);

        Livewire::test(Totalizer::class, ['page' => $page])
            ->assertSet('page', $page)
            ->assertSet('registration', $registration)
            ->assertSet('attendees', $attendees)
            ->assertSet('extras', $extras)
            ->assertSet('price', $price)
            ->assertSee(number_format($total, 2))
            ->assertSee(number_format($total_plus_vat, 2));

    } 

    public function test_totalizer_shows_correct_multiple_attendees_with_discount_no_extra_amount()
    {
        $page = Page::factory()->create();

        $promo = PromoCode::factory()->state([
            'page_id' => $page->id,
            'code' => 'Twenty',
            'discount' => 20
        ])->create();

        $registration = Registration::factory()->state([
            'page_id' => $page->id,
            'promo' => 'Twenty',
        ])->create();

        $group = PricingGroup::factory()->state([
            'page_id' => $page->id  
        ])->create();

        $price = PricingGroupPrice::factory()->create([
            'pricing_group_id' => $group->id
        ]);

        $attendees = [
            [
                'forename' => 'Test1',
                'surname' => 'User1',
                'email' => 'test1@example.com'
            ],
            [
                'forename' => 'Test2',
                'surname' => 'User2',
                'email' => 'test2@example.com'
            ]            
        ];

        $extras = [];

        $attendees_total = $price->price * count($attendees);

        $extras_total = 0;

        $discount_total = ($attendees_total + $extras_total) * ($promo->discount / 100);

        $total = ($attendees_total + $extras_total) - $discount_total;

        $total_plus_vat = $total * 1.2;

        session(['registration' => $registration, 'attendees' => $attendees, 'extras' => $extras, 'price' => $price]);

        Livewire::test(Totalizer::class, ['page' => $page])
            ->assertSet('page', $page)
            ->assertSet('registration', $registration)
            ->assertSet('attendees', $attendees)
            ->assertSet('extras', $extras)
            ->assertSet('price', $price)
            ->assertSee(number_format($total, 2))
            ->assertSee(number_format($total_plus_vat, 2));

    } 
}