<?php

namespace Tests\Feature\Site\Livewire\Ecommerce;

use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Foundation\Testing\WithFaker;
use Tests\TestCase;
use Livewire\Livewire;

use App\Models\Page;

use App\Http\Livewire\Layout\PageLayout;
use App\Http\Livewire\Forms\DynamicForm;

class PageTest extends TestCase
{
    use RefreshDatabase;

    public function test_page_layout_renders()
    {
        $page = Page::factory()->create();
        $layout = [];

        $response = $this->get(route('page', ['page' => $page->slug]));
        $response
            ->assertSeeLivewire(PageLayout::class)
            ->assertStatus(200);

    }

    public function test_page_layout_sets_properties()
    {
        $page = Page::factory()->create();
        $layout = [];

        Livewire::test(PageLayout::class, ['page' => $page])
            ->assertSet('page', $page)
            ->assertSet('layout', $layout);
    }

    public function test_page_layout_renders_form()
    {
        $layout = [
            [
                "id" => "2056ca72c5",
                "form" => 1,
                "name" => "Registration",
                "type" => "blocks.form-block",
                "blocks" => "page",
            ]
        ];

        $page = Page::factory()->state(['layout' => json_encode($layout)])->create();

        Livewire::test(PageLayout::class, ['page' => $page])
            ->assertSet('page', $page)
            ->assertSet('layout', $layout)
            ->assertSeeLivewire(DynamicForm::class);        
    }    
}