<?php

namespace Tests\Unit;

use Illuminate\Foundation\Testing\RefreshDatabase;
use Tests\TestCase;

use App\Actions\Forms\CheckForFreeRegistration;

use App\Models\Registration;
use App\Models\PromoCode;

class CheckForFreeRegistrationTest extends TestCase
{
    use RefreshDatabase;

    public function test_no_promo_code_no_discount()
    {
        $registration = Registration::factory()->create();
        
        $result = (new CheckForFreeRegistration)->execute($registration);

        $this->assertFalse($result);
    }

    public function test_promo_code_not_found_no_discount()
    {
        $registration = Registration::factory()->state(['promo' => 'NOTFOUND'])->create();
        
        $result = (new CheckForFreeRegistration)->execute($registration);

        $this->assertFalse($result);
    }

    public function test_promo_code_found_discount_not_100()
    {
        $code = PromoCode::factory()->state([
            'code' => 'DISCOUNT',
            'discount' => 50,
        ])->create();

        $registration = Registration::factory()->state(['promo' => 'DISCOUNT'])->create();
        
        $result = (new CheckForFreeRegistration)->execute($registration);

        $this->assertFalse($result);            
    }

    public function test_promo_code_found_discount_100_so_free()
    {
        $code = PromoCode::factory()->state([
            'code' => 'FREE',
            'discount' => 100,
        ])->create();

        $registration = Registration::factory()->state(['promo' => 'FREE'])->create();
        
        $result = (new CheckForFreeRegistration)->execute($registration);

        $this->assertTrue($result);

        $registration->fresh();

        $this->assertEquals(1, $registration->status);
    }
}
