<?php

namespace Tests\Unit;

use Illuminate\Foundation\Testing\RefreshDatabase;

use Tests\TestCase;

use App\Models\Page;
use App\Models\PricingGroup;
use App\Models\PricingGroupPrice;
use App\Models\Registration;
use App\Models\Attendee;

use App\Jobs\ProcessStripeWebhook;

class ProcessStripeWebhookTest extends TestCase
{
    use RefreshDatabase;

    public function test_payment_from_stripe_updates_registration_sends_emails()
    {
        $page = Page::factory()->create();

        $group = PricingGroup::factory()->state([
            'page_id' => $page->id  
        ])->create();

        $price = PricingGroupPrice::factory()->create([
            'pricing_group_id' => $group->id
        ]);

        $registration = Registration::factory()->state([
            'page_id' => $page->id
        ])->create();

        $attendee = Attendee::factory()->create(['registration_id' => $registration->id]);

        $event = new \stdClass();
        $event->data = new \stdClass();
        $event->data->object = new \stdClass();
        $event->data->object->id = 'Testing';
        $event->data->object->amount = $price->price * 100;
        $event->data->object->metadata = new \stdClass();
        $event->data->object->metadata->registration = $registration->id;

        $this->assertDatabaseHas('registrations', ['id' => $registration->id, 'status' => 0]);

        $process = new ProcessStripeWebhook($event, 'admin@example.com');
        $process->handle();

        $this->assertDatabaseHas('registrations', ['id' => $registration->id, 'status' => 2]);
        $this->assertDatabaseHas('transactions', ['reference' => 'Testing', 'gateway' => 'stripe', 'amount' => $price->price]);
        $this->assertDatabaseCount('jobs', 2);
    }

}