<?php

namespace Tests\Unit;

use Illuminate\Foundation\Testing\RefreshDatabase;

use Tests\TestCase;

use App\Models\Registration;
use App\Models\Attendee;
use App\Models\User;

use App\Observers\RegistrationObserver;

class RegistrationObserverTest extends TestCase
{
    use RefreshDatabase;

    public function test_portal_not_chosen_user_not_created()
    {
        $registration = Registration::factory()->state([
            'portal' => 0
        ])->create();

        $observer = new RegistrationObserver();

        $observer->updated($registration);

        $this->assertDatabaseCount('users', 0);
    }

    public function test_portal_chosen_user_not_created_status_not_free_or_paid()
    {
        $registration = Registration::factory()->state([
            'portal' => 1,
            'status' => 0
        ])->create();

        $observer = new RegistrationObserver();

        $observer->updated($registration);

        $this->assertDatabaseCount('users', 0);
    }    

    public function test_portal_chosen_user_created_status_free()
    {
        $registration = Registration::factory()->state([
            'portal' => 1,
            'status' => 1
        ])->create();

        $attendee = Attendee::factory()->state([
            'registration_id' => $registration->id    
        ])->create();

        $observer = new RegistrationObserver();

        $observer->updated($registration);

        $this->assertDatabaseCount('users', 1);
    }  
    
    public function test_portal_chosen_user_created_status_paid()
    {
        $registration = Registration::factory()->state([
            'portal' => 1,
            'status' => 2
        ])->create();

        $attendee = Attendee::factory()->state([
            'registration_id' => $registration->id    
        ])->create();

        $observer = new RegistrationObserver();

        $observer->updated($registration);

        $this->assertDatabaseCount('users', 1);
    }      
    
    public function test_portal_chosen_user_not_created_as_exists_status_free()
    {
        $registration = Registration::factory()->state([
            'portal' => 1,
            'status' => 1
        ])->create();

        $attendee = Attendee::factory()->state([
            'registration_id' => $registration->id    
        ])->create();

        $user = User::factory()->create([
            'email' => $attendee->email
        ]);

        $this->assertDatabaseCount('users', 1);
        $this->assertDatabaseHas('users', [
            'email' => $attendee->email
        ]);

        $observer = new RegistrationObserver();

        $observer->updated($registration);

        $this->assertDatabaseCount('users', 1);
        $this->assertDatabaseHas('users', [
            'email' => $attendee->email
        ]);        
    } 

    public function test_portal_chosen_user_not_created_as_exists_status_paid()
    {
        $registration = Registration::factory()->state([
            'portal' => 1,
            'status' => 2
        ])->create();

        $attendee = Attendee::factory()->state([
            'registration_id' => $registration->id    
        ])->create();

        $user = User::factory()->create([
            'email' => $attendee->email
        ]);

        $this->assertDatabaseCount('users', 1);
        $this->assertDatabaseHas('users', [
            'email' => $attendee->email
        ]);

        $observer = new RegistrationObserver();

        $observer->updated($registration);

        $this->assertDatabaseCount('users', 1);
        $this->assertDatabaseHas('users', [
            'email' => $attendee->email
        ]);        
    }     
}