<?php

namespace Tests\Unit;

use Illuminate\Foundation\Testing\RefreshDatabase;

use Tests\TestCase;

use App\Actions\Forms\ResolveModelProperties;

use App\Models\Country;

class ResolveModelPropertiesTest extends TestCase
{
    use RefreshDatabase;

    public function test_model_properties_no_exceptions()
    {
        $properties = (new ResolveModelProperties)->execute(Country::class, []);

        $this->assertIsArray($properties);
        $this->assertContains('id', $properties);
        $this->assertContains('region_id', $properties);
        $this->assertContains('name', $properties);
        $this->assertContains('created_at', $properties);
        $this->assertContains('updated_at', $properties);
    }

    public function test_model_properties_single_exception()
    {
        $properties = (new ResolveModelProperties)->execute(Country::class, ['id']);

        $this->assertIsArray($properties);

        $this->assertNotContains('id', $properties);
        $this->assertContains('region_id', $properties);
        $this->assertContains('name', $properties);
        $this->assertContains('created_at', $properties);
        $this->assertContains('updated_at', $properties);
    }

    public function test_model_properties_multiple_exceptions()
    {
        $properties = (new ResolveModelProperties)->execute(Country::class, ['id', 'region_id']);

        $this->assertIsArray($properties);

        $this->assertNotContains('id', $properties);
        $this->assertNotContains('region_id', $properties);
        $this->assertContains('name', $properties);
        $this->assertContains('created_at', $properties);
        $this->assertContains('updated_at', $properties);
    }
}