<?php

namespace Tests\Unit;

use Illuminate\Foundation\Testing\RefreshDatabase;

use Tests\TestCase;

use App\Models\Country;

use App\Actions\Forms\ResolveRelationsData;

class ResolveRelationsDataTest extends TestCase
{
    use RefreshDatabase;

    public function test_returns_data_when_needs_to_be_resolved()
    {
        $country = Country::factory()->create();

        $fields = [
            [
                "id" => "1465ce37d49",
                "name" => "Country ID",
                "slug" => "country_id",
                "type" => "selects.country-select",
                "label" => "Country",
                "model" => "App\\Models\\Country",
            ]
        ];

        $input = [
            "country_id" => $country->id
        ];
   
        $result = (new ResolveRelationsData)->execute($fields, $input);

        $this->assertIsArray($result);
        $this->assertArrayHasKey('country_id', $result);
        $this->assertContains($input['country_id'], $result);
        $this->assertArrayHasKey('country', $result);
        $this->assertContains($country->name, $result);
    }

    public function test_returns_data_when_no_fields_need_to_be_resolved()
    {

        $fields = [
            [
                "id" => "1465ce37d49",
                "name" => "Name",
                "slug" => "name",
                "type" => "inputs.text-input",
                "label" => "Name",
            ]
        ];

        $input = [
            "name" => "Test"
        ];

        $result = (new ResolveRelationsData)->execute($fields, $input);

        $this->assertIsArray($result);
        $this->assertArrayHasKey('name', $result);
        $this->assertContains($input['name'], $result);
    }

    public function test_returns_data_when_some_need_resolved_others_dont()
    {
        $country = Country::factory()->create();

        $fields = [
            [
                "id" => "1465ce37d49",
                "name" => "Name",
                "slug" => "name",
                "type" => "inputs.text-input",
                "label" => "Name",
            ],
            [
                "id" => "1465ce37d49",
                "name" => "Country ID",
                "slug" => "country_id",
                "type" => "selects.country-select",
                "label" => "Country",
                "model" => "App\\Models\\Country",
            ]            
        ];

        $input = [
            "name" => "Test",
            "country_id" => $country->id
        ];

        $result = (new ResolveRelationsData)->execute($fields, $input);

        $this->assertIsArray($result);
        $this->assertArrayHasKey('name', $result);
        $this->assertContains($input['name'], $result);
        $this->assertArrayHasKey('country_id', $result);
        $this->assertContains($input['country_id'], $result);
        $this->assertArrayHasKey('country', $result);
        $this->assertContains($country->name, $result);
    }

    public function test_returns_data_when_cant_find_to_resolve()
    {
        $fields = [
            [
                "id" => "1465ce37d49",
                "name" => "Name",
                "slug" => "name",
                "type" => "inputs.text-input",
                "label" => "Name",
            ],
            [
                "id" => "1465ce37d49",
                "name" => "Country ID",
                "slug" => "country_id",
                "type" => "selects.country-select",
                "label" => "Country",
                "model" => "App\\Models\\Country",
            ]            
        ];

        $input = [
            "name" => "Test",
            "country_id" => 99
        ];

        $result = (new ResolveRelationsData)->execute($fields, $input);

        $this->assertIsArray($result);
        $this->assertArrayHasKey('name', $result);
        $this->assertContains($input['name'], $result);
        $this->assertArrayHasKey('country_id', $result);
        $this->assertContains($input['country_id'], $result);
        $this->assertArrayNotHasKey('country', $result);

    }


}